/*******************************************************************************
* File Name: .h
* Version 3.50
*
* Description:
*  This file provides private constants and parameter values for the I2C
*  component.
*
* Note:
*
********************************************************************************
* Copyright 2012-2015, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_I2C_PVT_I2C_Slave_DUT_H)
#define CY_I2C_PVT_I2C_Slave_DUT_H

#include "I2C_Slave_DUT.h"

#define I2C_Slave_DUT_TIMEOUT_ENABLED_INC    (1u)
#if (0u != I2C_Slave_DUT_TIMEOUT_ENABLED_INC)
    #include "I2C_Slave_DUT_TMOUT.h"
#endif /* (0u != I2C_Slave_DUT_TIMEOUT_ENABLED_INC) */


/**********************************
*   Variables with external linkage
**********************************/

extern I2C_Slave_DUT_BACKUP_STRUCT I2C_Slave_DUT_backup;

extern volatile uint8 I2C_Slave_DUT_state;   /* Current state of I2C FSM */

/* Master variables */
#if (I2C_Slave_DUT_MODE_MASTER_ENABLED)
    extern volatile uint8 I2C_Slave_DUT_mstrStatus;   /* Master Status byte  */
    extern volatile uint8 I2C_Slave_DUT_mstrControl;  /* Master Control byte */

    /* Transmit buffer variables */
    extern volatile uint8 * I2C_Slave_DUT_mstrRdBufPtr;   /* Pointer to Master Read buffer */
    extern volatile uint8   I2C_Slave_DUT_mstrRdBufSize;  /* Master Read buffer size       */
    extern volatile uint8   I2C_Slave_DUT_mstrRdBufIndex; /* Master Read buffer Index      */

    /* Receive buffer variables */
    extern volatile uint8 * I2C_Slave_DUT_mstrWrBufPtr;   /* Pointer to Master Write buffer */
    extern volatile uint8   I2C_Slave_DUT_mstrWrBufSize;  /* Master Write buffer size       */
    extern volatile uint8   I2C_Slave_DUT_mstrWrBufIndex; /* Master Write buffer Index      */

#endif /* (I2C_Slave_DUT_MODE_MASTER_ENABLED) */

/* Slave variables */
#if (I2C_Slave_DUT_MODE_SLAVE_ENABLED)
    extern volatile uint8 I2C_Slave_DUT_slStatus;         /* Slave Status  */

    /* Transmit buffer variables */
    extern volatile uint8 * I2C_Slave_DUT_slRdBufPtr;     /* Pointer to Transmit buffer  */
    extern volatile uint8   I2C_Slave_DUT_slRdBufSize;    /* Slave Transmit buffer size  */
    extern volatile uint8   I2C_Slave_DUT_slRdBufIndex;   /* Slave Transmit buffer Index */

    /* Receive buffer variables */
    extern volatile uint8 * I2C_Slave_DUT_slWrBufPtr;     /* Pointer to Receive buffer  */
    extern volatile uint8   I2C_Slave_DUT_slWrBufSize;    /* Slave Receive buffer size  */
    extern volatile uint8   I2C_Slave_DUT_slWrBufIndex;   /* Slave Receive buffer Index */

    #if (I2C_Slave_DUT_SW_ADRR_DECODE)
        extern volatile uint8 I2C_Slave_DUT_slAddress;     /* Software address variable */
    #endif   /* (I2C_Slave_DUT_SW_ADRR_DECODE) */

#endif /* (I2C_Slave_DUT_MODE_SLAVE_ENABLED) */

#if ((I2C_Slave_DUT_FF_IMPLEMENTED) && (I2C_Slave_DUT_WAKEUP_ENABLED))
    extern volatile uint8 I2C_Slave_DUT_wakeupSource;
#endif /* ((I2C_Slave_DUT_FF_IMPLEMENTED) && (I2C_Slave_DUT_WAKEUP_ENABLED)) */


#endif /* CY_I2C_PVT_I2C_Slave_DUT_H */


/* [] END OF FILE */
