/*******************************************************************************
* File Name: OPTOMUX_SDA.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_OPTOMUX_SDA_H) /* Pins OPTOMUX_SDA_H */
#define CY_PINS_OPTOMUX_SDA_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "OPTOMUX_SDA_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 OPTOMUX_SDA__PORT == 15 && ((OPTOMUX_SDA__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    OPTOMUX_SDA_Write(uint8 value);
void    OPTOMUX_SDA_SetDriveMode(uint8 mode);
uint8   OPTOMUX_SDA_ReadDataReg(void);
uint8   OPTOMUX_SDA_Read(void);
void    OPTOMUX_SDA_SetInterruptMode(uint16 position, uint16 mode);
uint8   OPTOMUX_SDA_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the OPTOMUX_SDA_SetDriveMode() function.
     *  @{
     */
        #define OPTOMUX_SDA_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define OPTOMUX_SDA_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define OPTOMUX_SDA_DM_RES_UP          PIN_DM_RES_UP
        #define OPTOMUX_SDA_DM_RES_DWN         PIN_DM_RES_DWN
        #define OPTOMUX_SDA_DM_OD_LO           PIN_DM_OD_LO
        #define OPTOMUX_SDA_DM_OD_HI           PIN_DM_OD_HI
        #define OPTOMUX_SDA_DM_STRONG          PIN_DM_STRONG
        #define OPTOMUX_SDA_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define OPTOMUX_SDA_MASK               OPTOMUX_SDA__MASK
#define OPTOMUX_SDA_SHIFT              OPTOMUX_SDA__SHIFT
#define OPTOMUX_SDA_WIDTH              1u

/* Interrupt constants */
#if defined(OPTOMUX_SDA__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in OPTOMUX_SDA_SetInterruptMode() function.
     *  @{
     */
        #define OPTOMUX_SDA_INTR_NONE      (uint16)(0x0000u)
        #define OPTOMUX_SDA_INTR_RISING    (uint16)(0x0001u)
        #define OPTOMUX_SDA_INTR_FALLING   (uint16)(0x0002u)
        #define OPTOMUX_SDA_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define OPTOMUX_SDA_INTR_MASK      (0x01u) 
#endif /* (OPTOMUX_SDA__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define OPTOMUX_SDA_PS                     (* (reg8 *) OPTOMUX_SDA__PS)
/* Data Register */
#define OPTOMUX_SDA_DR                     (* (reg8 *) OPTOMUX_SDA__DR)
/* Port Number */
#define OPTOMUX_SDA_PRT_NUM                (* (reg8 *) OPTOMUX_SDA__PRT) 
/* Connect to Analog Globals */                                                  
#define OPTOMUX_SDA_AG                     (* (reg8 *) OPTOMUX_SDA__AG)                       
/* Analog MUX bux enable */
#define OPTOMUX_SDA_AMUX                   (* (reg8 *) OPTOMUX_SDA__AMUX) 
/* Bidirectional Enable */                                                        
#define OPTOMUX_SDA_BIE                    (* (reg8 *) OPTOMUX_SDA__BIE)
/* Bit-mask for Aliased Register Access */
#define OPTOMUX_SDA_BIT_MASK               (* (reg8 *) OPTOMUX_SDA__BIT_MASK)
/* Bypass Enable */
#define OPTOMUX_SDA_BYP                    (* (reg8 *) OPTOMUX_SDA__BYP)
/* Port wide control signals */                                                   
#define OPTOMUX_SDA_CTL                    (* (reg8 *) OPTOMUX_SDA__CTL)
/* Drive Modes */
#define OPTOMUX_SDA_DM0                    (* (reg8 *) OPTOMUX_SDA__DM0) 
#define OPTOMUX_SDA_DM1                    (* (reg8 *) OPTOMUX_SDA__DM1)
#define OPTOMUX_SDA_DM2                    (* (reg8 *) OPTOMUX_SDA__DM2) 
/* Input Buffer Disable Override */
#define OPTOMUX_SDA_INP_DIS                (* (reg8 *) OPTOMUX_SDA__INP_DIS)
/* LCD Common or Segment Drive */
#define OPTOMUX_SDA_LCD_COM_SEG            (* (reg8 *) OPTOMUX_SDA__LCD_COM_SEG)
/* Enable Segment LCD */
#define OPTOMUX_SDA_LCD_EN                 (* (reg8 *) OPTOMUX_SDA__LCD_EN)
/* Slew Rate Control */
#define OPTOMUX_SDA_SLW                    (* (reg8 *) OPTOMUX_SDA__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define OPTOMUX_SDA_PRTDSI__CAPS_SEL       (* (reg8 *) OPTOMUX_SDA__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define OPTOMUX_SDA_PRTDSI__DBL_SYNC_IN    (* (reg8 *) OPTOMUX_SDA__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define OPTOMUX_SDA_PRTDSI__OE_SEL0        (* (reg8 *) OPTOMUX_SDA__PRTDSI__OE_SEL0) 
#define OPTOMUX_SDA_PRTDSI__OE_SEL1        (* (reg8 *) OPTOMUX_SDA__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define OPTOMUX_SDA_PRTDSI__OUT_SEL0       (* (reg8 *) OPTOMUX_SDA__PRTDSI__OUT_SEL0) 
#define OPTOMUX_SDA_PRTDSI__OUT_SEL1       (* (reg8 *) OPTOMUX_SDA__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define OPTOMUX_SDA_PRTDSI__SYNC_OUT       (* (reg8 *) OPTOMUX_SDA__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(OPTOMUX_SDA__SIO_CFG)
    #define OPTOMUX_SDA_SIO_HYST_EN        (* (reg8 *) OPTOMUX_SDA__SIO_HYST_EN)
    #define OPTOMUX_SDA_SIO_REG_HIFREQ     (* (reg8 *) OPTOMUX_SDA__SIO_REG_HIFREQ)
    #define OPTOMUX_SDA_SIO_CFG            (* (reg8 *) OPTOMUX_SDA__SIO_CFG)
    #define OPTOMUX_SDA_SIO_DIFF           (* (reg8 *) OPTOMUX_SDA__SIO_DIFF)
#endif /* (OPTOMUX_SDA__SIO_CFG) */

/* Interrupt Registers */
#if defined(OPTOMUX_SDA__INTSTAT)
    #define OPTOMUX_SDA_INTSTAT            (* (reg8 *) OPTOMUX_SDA__INTSTAT)
    #define OPTOMUX_SDA_SNAP               (* (reg8 *) OPTOMUX_SDA__SNAP)
    
	#define OPTOMUX_SDA_0_INTTYPE_REG 		(* (reg8 *) OPTOMUX_SDA__0__INTTYPE)
#endif /* (OPTOMUX_SDA__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_OPTOMUX_SDA_H */


/* [] END OF FILE */
