/*******************************************************************************
* File Name: SPI_EXP_PORT_PM.c
* Version 2.50
*
* Description:
*  This file contains the setup, control and status commands to support
*  component operations in low power mode.
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "SPI_EXP_PORT_PVT.h"

static SPI_EXP_PORT_BACKUP_STRUCT SPI_EXP_PORT_backup =
{
    SPI_EXP_PORT_DISABLED,
    SPI_EXP_PORT_BITCTR_INIT,
};


/*******************************************************************************
* Function Name: SPI_EXP_PORT_SaveConfig
********************************************************************************
*
* Summary:
*  Empty function. Included for consistency with other components.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void SPI_EXP_PORT_SaveConfig(void) 
{

}


/*******************************************************************************
* Function Name: SPI_EXP_PORT_RestoreConfig
********************************************************************************
*
* Summary:
*  Empty function. Included for consistency with other components.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void SPI_EXP_PORT_RestoreConfig(void) 
{

}


/*******************************************************************************
* Function Name: SPI_EXP_PORT_Sleep
********************************************************************************
*
* Summary:
*  Prepare SPIM Component goes to sleep.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  SPI_EXP_PORT_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void SPI_EXP_PORT_Sleep(void) 
{
    /* Save components enable state */
    SPI_EXP_PORT_backup.enableState = ((uint8) SPI_EXP_PORT_IS_ENABLED);

    SPI_EXP_PORT_Stop();
}


/*******************************************************************************
* Function Name: SPI_EXP_PORT_Wakeup
********************************************************************************
*
* Summary:
*  Prepare SPIM Component to wake up.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  SPI_EXP_PORT_backup - used when non-retention registers are restored.
*  SPI_EXP_PORT_txBufferWrite - modified every function call - resets to
*  zero.
*  SPI_EXP_PORT_txBufferRead - modified every function call - resets to
*  zero.
*  SPI_EXP_PORT_rxBufferWrite - modified every function call - resets to
*  zero.
*  SPI_EXP_PORT_rxBufferRead - modified every function call - resets to
*  zero.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void SPI_EXP_PORT_Wakeup(void) 
{
    #if(SPI_EXP_PORT_RX_SOFTWARE_BUF_ENABLED)
        SPI_EXP_PORT_rxBufferFull  = 0u;
        SPI_EXP_PORT_rxBufferRead  = 0u;
        SPI_EXP_PORT_rxBufferWrite = 0u;
    #endif /* (SPI_EXP_PORT_RX_SOFTWARE_BUF_ENABLED) */

    #if(SPI_EXP_PORT_TX_SOFTWARE_BUF_ENABLED)
        SPI_EXP_PORT_txBufferFull  = 0u;
        SPI_EXP_PORT_txBufferRead  = 0u;
        SPI_EXP_PORT_txBufferWrite = 0u;
    #endif /* (SPI_EXP_PORT_TX_SOFTWARE_BUF_ENABLED) */

    /* Clear any data from the RX and TX FIFO */
    SPI_EXP_PORT_ClearFIFO();

    /* Restore components block enable state */
    if(0u != SPI_EXP_PORT_backup.enableState)
    {
        SPI_EXP_PORT_Enable();
    }
}


/* [] END OF FILE */
