/*******************************************************************************
* File Name: TimerOneHundredmSecond_PM.c
* Version 2.80
*
*  Description:
*     This file provides the power management source code to API for the
*     Timer.
*
*   Note:
*     None
*
*******************************************************************************
* Copyright 2008-2017, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
********************************************************************************/

#include "TimerOneHundredmSecond.h"

static TimerOneHundredmSecond_backupStruct TimerOneHundredmSecond_backup;


/*******************************************************************************
* Function Name: TimerOneHundredmSecond_SaveConfig
********************************************************************************
*
* Summary:
*     Save the current user configuration
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  TimerOneHundredmSecond_backup:  Variables of this global structure are modified to
*  store the values of non retention configuration registers when Sleep() API is
*  called.
*
*******************************************************************************/
void TimerOneHundredmSecond_SaveConfig(void) 
{
    #if (!TimerOneHundredmSecond_UsingFixedFunction)
        TimerOneHundredmSecond_backup.TimerUdb = TimerOneHundredmSecond_ReadCounter();
        TimerOneHundredmSecond_backup.InterruptMaskValue = TimerOneHundredmSecond_STATUS_MASK;
        #if (TimerOneHundredmSecond_UsingHWCaptureCounter)
            TimerOneHundredmSecond_backup.TimerCaptureCounter = TimerOneHundredmSecond_ReadCaptureCount();
        #endif /* Back Up capture counter register  */

        #if(!TimerOneHundredmSecond_UDB_CONTROL_REG_REMOVED)
            TimerOneHundredmSecond_backup.TimerControlRegister = TimerOneHundredmSecond_ReadControlRegister();
        #endif /* Backup the enable state of the Timer component */
    #endif /* Backup non retention registers in UDB implementation. All fixed function registers are retention */
}


/*******************************************************************************
* Function Name: TimerOneHundredmSecond_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  TimerOneHundredmSecond_backup:  Variables of this global structure are used to
*  restore the values of non retention registers on wakeup from sleep mode.
*
*******************************************************************************/
void TimerOneHundredmSecond_RestoreConfig(void) 
{   
    #if (!TimerOneHundredmSecond_UsingFixedFunction)

        TimerOneHundredmSecond_WriteCounter(TimerOneHundredmSecond_backup.TimerUdb);
        TimerOneHundredmSecond_STATUS_MASK =TimerOneHundredmSecond_backup.InterruptMaskValue;
        #if (TimerOneHundredmSecond_UsingHWCaptureCounter)
            TimerOneHundredmSecond_SetCaptureCount(TimerOneHundredmSecond_backup.TimerCaptureCounter);
        #endif /* Restore Capture counter register*/

        #if(!TimerOneHundredmSecond_UDB_CONTROL_REG_REMOVED)
            TimerOneHundredmSecond_WriteControlRegister(TimerOneHundredmSecond_backup.TimerControlRegister);
        #endif /* Restore the enable state of the Timer component */
    #endif /* Restore non retention registers in the UDB implementation only */
}


/*******************************************************************************
* Function Name: TimerOneHundredmSecond_Sleep
********************************************************************************
*
* Summary:
*     Stop and Save the user configuration
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  TimerOneHundredmSecond_backup.TimerEnableState:  Is modified depending on the
*  enable state of the block before entering sleep mode.
*
*******************************************************************************/
void TimerOneHundredmSecond_Sleep(void) 
{
    #if(!TimerOneHundredmSecond_UDB_CONTROL_REG_REMOVED)
        /* Save Counter's enable state */
        if(TimerOneHundredmSecond_CTRL_ENABLE == (TimerOneHundredmSecond_CONTROL & TimerOneHundredmSecond_CTRL_ENABLE))
        {
            /* Timer is enabled */
            TimerOneHundredmSecond_backup.TimerEnableState = 1u;
        }
        else
        {
            /* Timer is disabled */
            TimerOneHundredmSecond_backup.TimerEnableState = 0u;
        }
    #endif /* Back up enable state from the Timer control register */
    TimerOneHundredmSecond_Stop();
    TimerOneHundredmSecond_SaveConfig();
}


/*******************************************************************************
* Function Name: TimerOneHundredmSecond_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  TimerOneHundredmSecond_backup.enableState:  Is used to restore the enable state of
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void TimerOneHundredmSecond_Wakeup(void) 
{
    TimerOneHundredmSecond_RestoreConfig();
    #if(!TimerOneHundredmSecond_UDB_CONTROL_REG_REMOVED)
        if(TimerOneHundredmSecond_backup.TimerEnableState == 1u)
        {     /* Enable Timer's operation */
                TimerOneHundredmSecond_Enable();
        } /* Do nothing if Timer was disabled before */
    #endif /* Remove this code section if Control register is removed */
}


/* [] END OF FILE */
