/*******************************************************************************
* File Name: UARTDEBUG.c
* Version 2.50
*
* Description:
*  This file provides all API functionality of the UART component
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "UARTDEBUG.h"
#if (UARTDEBUG_INTERNAL_CLOCK_USED)
    #include "UARTDEBUG_IntClock.h"
#endif /* End UARTDEBUG_INTERNAL_CLOCK_USED */


/***************************************
* Global data allocation
***************************************/

uint8 UARTDEBUG_initVar = 0u;

#if (UARTDEBUG_TX_INTERRUPT_ENABLED && UARTDEBUG_TX_ENABLED)
    volatile uint8 UARTDEBUG_txBuffer[UARTDEBUG_TX_BUFFER_SIZE];
    volatile uint8 UARTDEBUG_txBufferRead = 0u;
    uint8 UARTDEBUG_txBufferWrite = 0u;
#endif /* (UARTDEBUG_TX_INTERRUPT_ENABLED && UARTDEBUG_TX_ENABLED) */

#if (UARTDEBUG_RX_INTERRUPT_ENABLED && (UARTDEBUG_RX_ENABLED || UARTDEBUG_HD_ENABLED))
    uint8 UARTDEBUG_errorStatus = 0u;
    volatile uint8 UARTDEBUG_rxBuffer[UARTDEBUG_RX_BUFFER_SIZE];
    volatile uint8 UARTDEBUG_rxBufferRead  = 0u;
    volatile uint8 UARTDEBUG_rxBufferWrite = 0u;
    volatile uint8 UARTDEBUG_rxBufferLoopDetect = 0u;
    volatile uint8 UARTDEBUG_rxBufferOverflow   = 0u;
    #if (UARTDEBUG_RXHW_ADDRESS_ENABLED)
        volatile uint8 UARTDEBUG_rxAddressMode = UARTDEBUG_RX_ADDRESS_MODE;
        volatile uint8 UARTDEBUG_rxAddressDetected = 0u;
    #endif /* (UARTDEBUG_RXHW_ADDRESS_ENABLED) */
#endif /* (UARTDEBUG_RX_INTERRUPT_ENABLED && (UARTDEBUG_RX_ENABLED || UARTDEBUG_HD_ENABLED)) */


/*******************************************************************************
* Function Name: UARTDEBUG_Start
********************************************************************************
*
* Summary:
*  This is the preferred method to begin component operation.
*  UARTDEBUG_Start() sets the initVar variable, calls the
*  UARTDEBUG_Init() function, and then calls the
*  UARTDEBUG_Enable() function.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global variables:
*  The UARTDEBUG_intiVar variable is used to indicate initial
*  configuration of this component. The variable is initialized to zero (0u)
*  and set to one (1u) the first time UARTDEBUG_Start() is called. This
*  allows for component initialization without re-initialization in all
*  subsequent calls to the UARTDEBUG_Start() routine.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void UARTDEBUG_Start(void) 
{
    /* If not initialized then initialize all required hardware and software */
    if(UARTDEBUG_initVar == 0u)
    {
        UARTDEBUG_Init();
        UARTDEBUG_initVar = 1u;
    }

    UARTDEBUG_Enable();
}


/*******************************************************************************
* Function Name: UARTDEBUG_Init
********************************************************************************
*
* Summary:
*  Initializes or restores the component according to the customizer Configure
*  dialog settings. It is not necessary to call UARTDEBUG_Init() because
*  the UARTDEBUG_Start() API calls this function and is the preferred
*  method to begin component operation.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void UARTDEBUG_Init(void) 
{
    #if(UARTDEBUG_RX_ENABLED || UARTDEBUG_HD_ENABLED)

        #if (UARTDEBUG_RX_INTERRUPT_ENABLED)
            /* Set RX interrupt vector and priority */
            (void) CyIntSetVector(UARTDEBUG_RX_VECT_NUM, &UARTDEBUG_RXISR);
            CyIntSetPriority(UARTDEBUG_RX_VECT_NUM, UARTDEBUG_RX_PRIOR_NUM);
            UARTDEBUG_errorStatus = 0u;
        #endif /* (UARTDEBUG_RX_INTERRUPT_ENABLED) */

        #if (UARTDEBUG_RXHW_ADDRESS_ENABLED)
            UARTDEBUG_SetRxAddressMode(UARTDEBUG_RX_ADDRESS_MODE);
            UARTDEBUG_SetRxAddress1(UARTDEBUG_RX_HW_ADDRESS1);
            UARTDEBUG_SetRxAddress2(UARTDEBUG_RX_HW_ADDRESS2);
        #endif /* End UARTDEBUG_RXHW_ADDRESS_ENABLED */

        /* Init Count7 period */
        UARTDEBUG_RXBITCTR_PERIOD_REG = UARTDEBUG_RXBITCTR_INIT;
        /* Configure the Initial RX interrupt mask */
        UARTDEBUG_RXSTATUS_MASK_REG  = UARTDEBUG_INIT_RX_INTERRUPTS_MASK;
    #endif /* End UARTDEBUG_RX_ENABLED || UARTDEBUG_HD_ENABLED*/

    #if(UARTDEBUG_TX_ENABLED)
        #if (UARTDEBUG_TX_INTERRUPT_ENABLED)
            /* Set TX interrupt vector and priority */
            (void) CyIntSetVector(UARTDEBUG_TX_VECT_NUM, &UARTDEBUG_TXISR);
            CyIntSetPriority(UARTDEBUG_TX_VECT_NUM, UARTDEBUG_TX_PRIOR_NUM);
        #endif /* (UARTDEBUG_TX_INTERRUPT_ENABLED) */

        /* Write Counter Value for TX Bit Clk Generator*/
        #if (UARTDEBUG_TXCLKGEN_DP)
            UARTDEBUG_TXBITCLKGEN_CTR_REG = UARTDEBUG_BIT_CENTER;
            UARTDEBUG_TXBITCLKTX_COMPLETE_REG = ((UARTDEBUG_NUMBER_OF_DATA_BITS +
                        UARTDEBUG_NUMBER_OF_START_BIT) * UARTDEBUG_OVER_SAMPLE_COUNT) - 1u;
        #else
            UARTDEBUG_TXBITCTR_PERIOD_REG = ((UARTDEBUG_NUMBER_OF_DATA_BITS +
                        UARTDEBUG_NUMBER_OF_START_BIT) * UARTDEBUG_OVER_SAMPLE_8) - 1u;
        #endif /* End UARTDEBUG_TXCLKGEN_DP */

        /* Configure the Initial TX interrupt mask */
        #if (UARTDEBUG_TX_INTERRUPT_ENABLED)
            UARTDEBUG_TXSTATUS_MASK_REG = UARTDEBUG_TX_STS_FIFO_EMPTY;
        #else
            UARTDEBUG_TXSTATUS_MASK_REG = UARTDEBUG_INIT_TX_INTERRUPTS_MASK;
        #endif /*End UARTDEBUG_TX_INTERRUPT_ENABLED*/

    #endif /* End UARTDEBUG_TX_ENABLED */

    #if(UARTDEBUG_PARITY_TYPE_SW)  /* Write Parity to Control Register */
        UARTDEBUG_WriteControlRegister( \
            (UARTDEBUG_ReadControlRegister() & (uint8)~UARTDEBUG_CTRL_PARITY_TYPE_MASK) | \
            (uint8)(UARTDEBUG_PARITY_TYPE << UARTDEBUG_CTRL_PARITY_TYPE0_SHIFT) );
    #endif /* End UARTDEBUG_PARITY_TYPE_SW */
}


/*******************************************************************************
* Function Name: UARTDEBUG_Enable
********************************************************************************
*
* Summary:
*  Activates the hardware and begins component operation. It is not necessary
*  to call UARTDEBUG_Enable() because the UARTDEBUG_Start() API
*  calls this function, which is the preferred method to begin component
*  operation.

* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  UARTDEBUG_rxAddressDetected - set to initial state (0).
*
*******************************************************************************/
void UARTDEBUG_Enable(void) 
{
    uint8 enableInterrupts;
    enableInterrupts = CyEnterCriticalSection();

    #if (UARTDEBUG_RX_ENABLED || UARTDEBUG_HD_ENABLED)
        /* RX Counter (Count7) Enable */
        UARTDEBUG_RXBITCTR_CONTROL_REG |= UARTDEBUG_CNTR_ENABLE;

        /* Enable the RX Interrupt */
        UARTDEBUG_RXSTATUS_ACTL_REG  |= UARTDEBUG_INT_ENABLE;

        #if (UARTDEBUG_RX_INTERRUPT_ENABLED)
            UARTDEBUG_EnableRxInt();

            #if (UARTDEBUG_RXHW_ADDRESS_ENABLED)
                UARTDEBUG_rxAddressDetected = 0u;
            #endif /* (UARTDEBUG_RXHW_ADDRESS_ENABLED) */
        #endif /* (UARTDEBUG_RX_INTERRUPT_ENABLED) */
    #endif /* (UARTDEBUG_RX_ENABLED || UARTDEBUG_HD_ENABLED) */

    #if(UARTDEBUG_TX_ENABLED)
        /* TX Counter (DP/Count7) Enable */
        #if(!UARTDEBUG_TXCLKGEN_DP)
            UARTDEBUG_TXBITCTR_CONTROL_REG |= UARTDEBUG_CNTR_ENABLE;
        #endif /* End UARTDEBUG_TXCLKGEN_DP */

        /* Enable the TX Interrupt */
        UARTDEBUG_TXSTATUS_ACTL_REG |= UARTDEBUG_INT_ENABLE;
        #if (UARTDEBUG_TX_INTERRUPT_ENABLED)
            UARTDEBUG_ClearPendingTxInt(); /* Clear history of TX_NOT_EMPTY */
            UARTDEBUG_EnableTxInt();
        #endif /* (UARTDEBUG_TX_INTERRUPT_ENABLED) */
     #endif /* (UARTDEBUG_TX_INTERRUPT_ENABLED) */

    #if (UARTDEBUG_INTERNAL_CLOCK_USED)
        UARTDEBUG_IntClock_Start();  /* Enable the clock */
    #endif /* (UARTDEBUG_INTERNAL_CLOCK_USED) */

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: UARTDEBUG_Stop
********************************************************************************
*
* Summary:
*  Disables the UART operation.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void UARTDEBUG_Stop(void) 
{
    uint8 enableInterrupts;
    enableInterrupts = CyEnterCriticalSection();

    /* Write Bit Counter Disable */
    #if (UARTDEBUG_RX_ENABLED || UARTDEBUG_HD_ENABLED)
        UARTDEBUG_RXBITCTR_CONTROL_REG &= (uint8) ~UARTDEBUG_CNTR_ENABLE;
    #endif /* (UARTDEBUG_RX_ENABLED || UARTDEBUG_HD_ENABLED) */

    #if (UARTDEBUG_TX_ENABLED)
        #if(!UARTDEBUG_TXCLKGEN_DP)
            UARTDEBUG_TXBITCTR_CONTROL_REG &= (uint8) ~UARTDEBUG_CNTR_ENABLE;
        #endif /* (!UARTDEBUG_TXCLKGEN_DP) */
    #endif /* (UARTDEBUG_TX_ENABLED) */

    #if (UARTDEBUG_INTERNAL_CLOCK_USED)
        UARTDEBUG_IntClock_Stop();   /* Disable the clock */
    #endif /* (UARTDEBUG_INTERNAL_CLOCK_USED) */

    /* Disable internal interrupt component */
    #if (UARTDEBUG_RX_ENABLED || UARTDEBUG_HD_ENABLED)
        UARTDEBUG_RXSTATUS_ACTL_REG  &= (uint8) ~UARTDEBUG_INT_ENABLE;

        #if (UARTDEBUG_RX_INTERRUPT_ENABLED)
            UARTDEBUG_DisableRxInt();
        #endif /* (UARTDEBUG_RX_INTERRUPT_ENABLED) */
    #endif /* (UARTDEBUG_RX_ENABLED || UARTDEBUG_HD_ENABLED) */

    #if (UARTDEBUG_TX_ENABLED)
        UARTDEBUG_TXSTATUS_ACTL_REG &= (uint8) ~UARTDEBUG_INT_ENABLE;

        #if (UARTDEBUG_TX_INTERRUPT_ENABLED)
            UARTDEBUG_DisableTxInt();
        #endif /* (UARTDEBUG_TX_INTERRUPT_ENABLED) */
    #endif /* (UARTDEBUG_TX_ENABLED) */

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: UARTDEBUG_ReadControlRegister
********************************************************************************
*
* Summary:
*  Returns the current value of the control register.
*
* Parameters:
*  None.
*
* Return:
*  Contents of the control register.
*
*******************************************************************************/
uint8 UARTDEBUG_ReadControlRegister(void) 
{
    #if (UARTDEBUG_CONTROL_REG_REMOVED)
        return(0u);
    #else
        return(UARTDEBUG_CONTROL_REG);
    #endif /* (UARTDEBUG_CONTROL_REG_REMOVED) */
}


/*******************************************************************************
* Function Name: UARTDEBUG_WriteControlRegister
********************************************************************************
*
* Summary:
*  Writes an 8-bit value into the control register
*
* Parameters:
*  control:  control register value
*
* Return:
*  None.
*
*******************************************************************************/
void  UARTDEBUG_WriteControlRegister(uint8 control) 
{
    #if (UARTDEBUG_CONTROL_REG_REMOVED)
        if(0u != control)
        {
            /* Suppress compiler warning */
        }
    #else
       UARTDEBUG_CONTROL_REG = control;
    #endif /* (UARTDEBUG_CONTROL_REG_REMOVED) */
}


#if(UARTDEBUG_RX_ENABLED || UARTDEBUG_HD_ENABLED)
    /*******************************************************************************
    * Function Name: UARTDEBUG_SetRxInterruptMode
    ********************************************************************************
    *
    * Summary:
    *  Configures the RX interrupt sources enabled.
    *
    * Parameters:
    *  IntSrc:  Bit field containing the RX interrupts to enable. Based on the 
    *  bit-field arrangement of the status register. This value must be a 
    *  combination of status register bit-masks shown below:
    *      UARTDEBUG_RX_STS_FIFO_NOTEMPTY    Interrupt on byte received.
    *      UARTDEBUG_RX_STS_PAR_ERROR        Interrupt on parity error.
    *      UARTDEBUG_RX_STS_STOP_ERROR       Interrupt on stop error.
    *      UARTDEBUG_RX_STS_BREAK            Interrupt on break.
    *      UARTDEBUG_RX_STS_OVERRUN          Interrupt on overrun error.
    *      UARTDEBUG_RX_STS_ADDR_MATCH       Interrupt on address match.
    *      UARTDEBUG_RX_STS_MRKSPC           Interrupt on address detect.
    *
    * Return:
    *  None.
    *
    * Theory:
    *  Enables the output of specific status bits to the interrupt controller
    *
    *******************************************************************************/
    void UARTDEBUG_SetRxInterruptMode(uint8 intSrc) 
    {
        UARTDEBUG_RXSTATUS_MASK_REG  = intSrc;
    }


    /*******************************************************************************
    * Function Name: UARTDEBUG_ReadRxData
    ********************************************************************************
    *
    * Summary:
    *  Returns the next byte of received data. This function returns data without
    *  checking the status. You must check the status separately.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  Received data from RX register
    *
    * Global Variables:
    *  UARTDEBUG_rxBuffer - RAM buffer pointer for save received data.
    *  UARTDEBUG_rxBufferWrite - cyclic index for write to rxBuffer,
    *     checked to identify new data.
    *  UARTDEBUG_rxBufferRead - cyclic index for read from rxBuffer,
    *     incremented after each byte has been read from buffer.
    *  UARTDEBUG_rxBufferLoopDetect - cleared if loop condition was detected
    *     in RX ISR.
    *
    * Reentrant:
    *  No.
    *
    *******************************************************************************/
    uint8 UARTDEBUG_ReadRxData(void) 
    {
        uint8 rxData;

    #if (UARTDEBUG_RX_INTERRUPT_ENABLED)

        uint8 locRxBufferRead;
        uint8 locRxBufferWrite;

        /* Protect variables that could change on interrupt */
        UARTDEBUG_DisableRxInt();

        locRxBufferRead  = UARTDEBUG_rxBufferRead;
        locRxBufferWrite = UARTDEBUG_rxBufferWrite;

        if( (UARTDEBUG_rxBufferLoopDetect != 0u) || (locRxBufferRead != locRxBufferWrite) )
        {
            rxData = UARTDEBUG_rxBuffer[locRxBufferRead];
            locRxBufferRead++;

            if(locRxBufferRead >= UARTDEBUG_RX_BUFFER_SIZE)
            {
                locRxBufferRead = 0u;
            }
            /* Update the real pointer */
            UARTDEBUG_rxBufferRead = locRxBufferRead;

            if(UARTDEBUG_rxBufferLoopDetect != 0u)
            {
                UARTDEBUG_rxBufferLoopDetect = 0u;
                #if ((UARTDEBUG_RX_INTERRUPT_ENABLED) && (UARTDEBUG_FLOW_CONTROL != 0u))
                    /* When Hardware Flow Control selected - return RX mask */
                    #if( UARTDEBUG_HD_ENABLED )
                        if((UARTDEBUG_CONTROL_REG & UARTDEBUG_CTRL_HD_SEND) == 0u)
                        {   /* In Half duplex mode return RX mask only in RX
                            *  configuration set, otherwise
                            *  mask will be returned in LoadRxConfig() API.
                            */
                            UARTDEBUG_RXSTATUS_MASK_REG  |= UARTDEBUG_RX_STS_FIFO_NOTEMPTY;
                        }
                    #else
                        UARTDEBUG_RXSTATUS_MASK_REG  |= UARTDEBUG_RX_STS_FIFO_NOTEMPTY;
                    #endif /* end UARTDEBUG_HD_ENABLED */
                #endif /* ((UARTDEBUG_RX_INTERRUPT_ENABLED) && (UARTDEBUG_FLOW_CONTROL != 0u)) */
            }
        }
        else
        {   /* Needs to check status for RX_STS_FIFO_NOTEMPTY bit */
            rxData = UARTDEBUG_RXDATA_REG;
        }

        UARTDEBUG_EnableRxInt();

    #else

        /* Needs to check status for RX_STS_FIFO_NOTEMPTY bit */
        rxData = UARTDEBUG_RXDATA_REG;

    #endif /* (UARTDEBUG_RX_INTERRUPT_ENABLED) */

        return(rxData);
    }


    /*******************************************************************************
    * Function Name: UARTDEBUG_ReadRxStatus
    ********************************************************************************
    *
    * Summary:
    *  Returns the current state of the receiver status register and the software
    *  buffer overflow status.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  Current state of the status register.
    *
    * Side Effect:
    *  All status register bits are clear-on-read except
    *  UARTDEBUG_RX_STS_FIFO_NOTEMPTY.
    *  UARTDEBUG_RX_STS_FIFO_NOTEMPTY clears immediately after RX data
    *  register read.
    *
    * Global Variables:
    *  UARTDEBUG_rxBufferOverflow - used to indicate overload condition.
    *   It set to one in RX interrupt when there isn't free space in
    *   UARTDEBUG_rxBufferRead to write new data. This condition returned
    *   and cleared to zero by this API as an
    *   UARTDEBUG_RX_STS_SOFT_BUFF_OVER bit along with RX Status register
    *   bits.
    *
    *******************************************************************************/
    uint8 UARTDEBUG_ReadRxStatus(void) 
    {
        uint8 status;

        status = UARTDEBUG_RXSTATUS_REG & UARTDEBUG_RX_HW_MASK;

    #if (UARTDEBUG_RX_INTERRUPT_ENABLED)
        if(UARTDEBUG_rxBufferOverflow != 0u)
        {
            status |= UARTDEBUG_RX_STS_SOFT_BUFF_OVER;
            UARTDEBUG_rxBufferOverflow = 0u;
        }
    #endif /* (UARTDEBUG_RX_INTERRUPT_ENABLED) */

        return(status);
    }


    /*******************************************************************************
    * Function Name: UARTDEBUG_GetChar
    ********************************************************************************
    *
    * Summary:
    *  Returns the last received byte of data. UARTDEBUG_GetChar() is
    *  designed for ASCII characters and returns a uint8 where 1 to 255 are values
    *  for valid characters and 0 indicates an error occurred or no data is present.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  Character read from UART RX buffer. ASCII characters from 1 to 255 are valid.
    *  A returned zero signifies an error condition or no data available.
    *
    * Global Variables:
    *  UARTDEBUG_rxBuffer - RAM buffer pointer for save received data.
    *  UARTDEBUG_rxBufferWrite - cyclic index for write to rxBuffer,
    *     checked to identify new data.
    *  UARTDEBUG_rxBufferRead - cyclic index for read from rxBuffer,
    *     incremented after each byte has been read from buffer.
    *  UARTDEBUG_rxBufferLoopDetect - cleared if loop condition was detected
    *     in RX ISR.
    *
    * Reentrant:
    *  No.
    *
    *******************************************************************************/
    uint8 UARTDEBUG_GetChar(void) 
    {
        uint8 rxData = 0u;
        uint8 rxStatus;

    #if (UARTDEBUG_RX_INTERRUPT_ENABLED)
        uint8 locRxBufferRead;
        uint8 locRxBufferWrite;

        /* Protect variables that could change on interrupt */
        UARTDEBUG_DisableRxInt();

        locRxBufferRead  = UARTDEBUG_rxBufferRead;
        locRxBufferWrite = UARTDEBUG_rxBufferWrite;

        if( (UARTDEBUG_rxBufferLoopDetect != 0u) || (locRxBufferRead != locRxBufferWrite) )
        {
            rxData = UARTDEBUG_rxBuffer[locRxBufferRead];
            locRxBufferRead++;
            if(locRxBufferRead >= UARTDEBUG_RX_BUFFER_SIZE)
            {
                locRxBufferRead = 0u;
            }
            /* Update the real pointer */
            UARTDEBUG_rxBufferRead = locRxBufferRead;

            if(UARTDEBUG_rxBufferLoopDetect != 0u)
            {
                UARTDEBUG_rxBufferLoopDetect = 0u;
                #if( (UARTDEBUG_RX_INTERRUPT_ENABLED) && (UARTDEBUG_FLOW_CONTROL != 0u) )
                    /* When Hardware Flow Control selected - return RX mask */
                    #if( UARTDEBUG_HD_ENABLED )
                        if((UARTDEBUG_CONTROL_REG & UARTDEBUG_CTRL_HD_SEND) == 0u)
                        {   /* In Half duplex mode return RX mask only if
                            *  RX configuration set, otherwise
                            *  mask will be returned in LoadRxConfig() API.
                            */
                            UARTDEBUG_RXSTATUS_MASK_REG |= UARTDEBUG_RX_STS_FIFO_NOTEMPTY;
                        }
                    #else
                        UARTDEBUG_RXSTATUS_MASK_REG |= UARTDEBUG_RX_STS_FIFO_NOTEMPTY;
                    #endif /* end UARTDEBUG_HD_ENABLED */
                #endif /* UARTDEBUG_RX_INTERRUPT_ENABLED and Hardware flow control*/
            }

        }
        else
        {   rxStatus = UARTDEBUG_RXSTATUS_REG;
            if((rxStatus & UARTDEBUG_RX_STS_FIFO_NOTEMPTY) != 0u)
            {   /* Read received data from FIFO */
                rxData = UARTDEBUG_RXDATA_REG;
                /*Check status on error*/
                if((rxStatus & (UARTDEBUG_RX_STS_BREAK | UARTDEBUG_RX_STS_PAR_ERROR |
                                UARTDEBUG_RX_STS_STOP_ERROR | UARTDEBUG_RX_STS_OVERRUN)) != 0u)
                {
                    rxData = 0u;
                }
            }
        }

        UARTDEBUG_EnableRxInt();

    #else

        rxStatus =UARTDEBUG_RXSTATUS_REG;
        if((rxStatus & UARTDEBUG_RX_STS_FIFO_NOTEMPTY) != 0u)
        {
            /* Read received data from FIFO */
            rxData = UARTDEBUG_RXDATA_REG;

            /*Check status on error*/
            if((rxStatus & (UARTDEBUG_RX_STS_BREAK | UARTDEBUG_RX_STS_PAR_ERROR |
                            UARTDEBUG_RX_STS_STOP_ERROR | UARTDEBUG_RX_STS_OVERRUN)) != 0u)
            {
                rxData = 0u;
            }
        }
    #endif /* (UARTDEBUG_RX_INTERRUPT_ENABLED) */

        return(rxData);
    }


    /*******************************************************************************
    * Function Name: UARTDEBUG_GetByte
    ********************************************************************************
    *
    * Summary:
    *  Reads UART RX buffer immediately, returns received character and error
    *  condition.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  MSB contains status and LSB contains UART RX data. If the MSB is nonzero,
    *  an error has occurred.
    *
    * Reentrant:
    *  No.
    *
    *******************************************************************************/
    uint16 UARTDEBUG_GetByte(void) 
    {
        
    #if (UARTDEBUG_RX_INTERRUPT_ENABLED)
        uint16 locErrorStatus;
        /* Protect variables that could change on interrupt */
        UARTDEBUG_DisableRxInt();
        locErrorStatus = (uint16)UARTDEBUG_errorStatus;
        UARTDEBUG_errorStatus = 0u;
        UARTDEBUG_EnableRxInt();
        return ( (uint16)(locErrorStatus << 8u) | UARTDEBUG_ReadRxData() );
    #else
        return ( ((uint16)UARTDEBUG_ReadRxStatus() << 8u) | UARTDEBUG_ReadRxData() );
    #endif /* UARTDEBUG_RX_INTERRUPT_ENABLED */
        
    }


    /*******************************************************************************
    * Function Name: UARTDEBUG_GetRxBufferSize
    ********************************************************************************
    *
    * Summary:
    *  Returns the number of received bytes available in the RX buffer.
    *  * RX software buffer is disabled (RX Buffer Size parameter is equal to 4): 
    *    returns 0 for empty RX FIFO or 1 for not empty RX FIFO.
    *  * RX software buffer is enabled: returns the number of bytes available in 
    *    the RX software buffer. Bytes available in the RX FIFO do not take to 
    *    account.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  uint8: Number of bytes in the RX buffer. 
    *    Return value type depends on RX Buffer Size parameter.
    *
    * Global Variables:
    *  UARTDEBUG_rxBufferWrite - used to calculate left bytes.
    *  UARTDEBUG_rxBufferRead - used to calculate left bytes.
    *  UARTDEBUG_rxBufferLoopDetect - checked to decide left bytes amount.
    *
    * Reentrant:
    *  No.
    *
    * Theory:
    *  Allows the user to find out how full the RX Buffer is.
    *
    *******************************************************************************/
    uint8 UARTDEBUG_GetRxBufferSize(void)
                                                            
    {
        uint8 size;

    #if (UARTDEBUG_RX_INTERRUPT_ENABLED)

        /* Protect variables that could change on interrupt */
        UARTDEBUG_DisableRxInt();

        if(UARTDEBUG_rxBufferRead == UARTDEBUG_rxBufferWrite)
        {
            if(UARTDEBUG_rxBufferLoopDetect != 0u)
            {
                size = UARTDEBUG_RX_BUFFER_SIZE;
            }
            else
            {
                size = 0u;
            }
        }
        else if(UARTDEBUG_rxBufferRead < UARTDEBUG_rxBufferWrite)
        {
            size = (UARTDEBUG_rxBufferWrite - UARTDEBUG_rxBufferRead);
        }
        else
        {
            size = (UARTDEBUG_RX_BUFFER_SIZE - UARTDEBUG_rxBufferRead) + UARTDEBUG_rxBufferWrite;
        }

        UARTDEBUG_EnableRxInt();

    #else

        /* We can only know if there is data in the fifo. */
        size = ((UARTDEBUG_RXSTATUS_REG & UARTDEBUG_RX_STS_FIFO_NOTEMPTY) != 0u) ? 1u : 0u;

    #endif /* (UARTDEBUG_RX_INTERRUPT_ENABLED) */

        return(size);
    }


    /*******************************************************************************
    * Function Name: UARTDEBUG_ClearRxBuffer
    ********************************************************************************
    *
    * Summary:
    *  Clears the receiver memory buffer and hardware RX FIFO of all received data.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    * Global Variables:
    *  UARTDEBUG_rxBufferWrite - cleared to zero.
    *  UARTDEBUG_rxBufferRead - cleared to zero.
    *  UARTDEBUG_rxBufferLoopDetect - cleared to zero.
    *  UARTDEBUG_rxBufferOverflow - cleared to zero.
    *
    * Reentrant:
    *  No.
    *
    * Theory:
    *  Setting the pointers to zero makes the system believe there is no data to
    *  read and writing will resume at address 0 overwriting any data that may
    *  have remained in the RAM.
    *
    * Side Effects:
    *  Any received data not read from the RAM or FIFO buffer will be lost.
    *
    *******************************************************************************/
    void UARTDEBUG_ClearRxBuffer(void) 
    {
        uint8 enableInterrupts;

        /* Clear the HW FIFO */
        enableInterrupts = CyEnterCriticalSection();
        UARTDEBUG_RXDATA_AUX_CTL_REG |= (uint8)  UARTDEBUG_RX_FIFO_CLR;
        UARTDEBUG_RXDATA_AUX_CTL_REG &= (uint8) ~UARTDEBUG_RX_FIFO_CLR;
        CyExitCriticalSection(enableInterrupts);

    #if (UARTDEBUG_RX_INTERRUPT_ENABLED)

        /* Protect variables that could change on interrupt. */
        UARTDEBUG_DisableRxInt();

        UARTDEBUG_rxBufferRead = 0u;
        UARTDEBUG_rxBufferWrite = 0u;
        UARTDEBUG_rxBufferLoopDetect = 0u;
        UARTDEBUG_rxBufferOverflow = 0u;

        UARTDEBUG_EnableRxInt();

    #endif /* (UARTDEBUG_RX_INTERRUPT_ENABLED) */

    }


    /*******************************************************************************
    * Function Name: UARTDEBUG_SetRxAddressMode
    ********************************************************************************
    *
    * Summary:
    *  Sets the software controlled Addressing mode used by the RX portion of the
    *  UART.
    *
    * Parameters:
    *  addressMode: Enumerated value indicating the mode of RX addressing
    *  UARTDEBUG__B_UART__AM_SW_BYTE_BYTE -  Software Byte-by-Byte address
    *                                               detection
    *  UARTDEBUG__B_UART__AM_SW_DETECT_TO_BUFFER - Software Detect to Buffer
    *                                               address detection
    *  UARTDEBUG__B_UART__AM_HW_BYTE_BY_BYTE - Hardware Byte-by-Byte address
    *                                               detection
    *  UARTDEBUG__B_UART__AM_HW_DETECT_TO_BUFFER - Hardware Detect to Buffer
    *                                               address detection
    *  UARTDEBUG__B_UART__AM_NONE - No address detection
    *
    * Return:
    *  None.
    *
    * Global Variables:
    *  UARTDEBUG_rxAddressMode - the parameter stored in this variable for
    *   the farther usage in RX ISR.
    *  UARTDEBUG_rxAddressDetected - set to initial state (0).
    *
    *******************************************************************************/
    void UARTDEBUG_SetRxAddressMode(uint8 addressMode)
                                                        
    {
        #if(UARTDEBUG_RXHW_ADDRESS_ENABLED)
            #if(UARTDEBUG_CONTROL_REG_REMOVED)
                if(0u != addressMode)
                {
                    /* Suppress compiler warning */
                }
            #else /* UARTDEBUG_CONTROL_REG_REMOVED */
                uint8 tmpCtrl;
                tmpCtrl = UARTDEBUG_CONTROL_REG & (uint8)~UARTDEBUG_CTRL_RXADDR_MODE_MASK;
                tmpCtrl |= (uint8)(addressMode << UARTDEBUG_CTRL_RXADDR_MODE0_SHIFT);
                UARTDEBUG_CONTROL_REG = tmpCtrl;

                #if(UARTDEBUG_RX_INTERRUPT_ENABLED && \
                   (UARTDEBUG_RXBUFFERSIZE > UARTDEBUG_FIFO_LENGTH) )
                    UARTDEBUG_rxAddressMode = addressMode;
                    UARTDEBUG_rxAddressDetected = 0u;
                #endif /* End UARTDEBUG_RXBUFFERSIZE > UARTDEBUG_FIFO_LENGTH*/
            #endif /* End UARTDEBUG_CONTROL_REG_REMOVED */
        #else /* UARTDEBUG_RXHW_ADDRESS_ENABLED */
            if(0u != addressMode)
            {
                /* Suppress compiler warning */
            }
        #endif /* End UARTDEBUG_RXHW_ADDRESS_ENABLED */
    }


    /*******************************************************************************
    * Function Name: UARTDEBUG_SetRxAddress1
    ********************************************************************************
    *
    * Summary:
    *  Sets the first of two hardware-detectable receiver addresses.
    *
    * Parameters:
    *  address: Address #1 for hardware address detection.
    *
    * Return:
    *  None.
    *
    *******************************************************************************/
    void UARTDEBUG_SetRxAddress1(uint8 address) 
    {
        UARTDEBUG_RXADDRESS1_REG = address;
    }


    /*******************************************************************************
    * Function Name: UARTDEBUG_SetRxAddress2
    ********************************************************************************
    *
    * Summary:
    *  Sets the second of two hardware-detectable receiver addresses.
    *
    * Parameters:
    *  address: Address #2 for hardware address detection.
    *
    * Return:
    *  None.
    *
    *******************************************************************************/
    void UARTDEBUG_SetRxAddress2(uint8 address) 
    {
        UARTDEBUG_RXADDRESS2_REG = address;
    }

#endif  /* UARTDEBUG_RX_ENABLED || UARTDEBUG_HD_ENABLED*/


#if( (UARTDEBUG_TX_ENABLED) || (UARTDEBUG_HD_ENABLED) )
    /*******************************************************************************
    * Function Name: UARTDEBUG_SetTxInterruptMode
    ********************************************************************************
    *
    * Summary:
    *  Configures the TX interrupt sources to be enabled, but does not enable the
    *  interrupt.
    *
    * Parameters:
    *  intSrc: Bit field containing the TX interrupt sources to enable
    *   UARTDEBUG_TX_STS_COMPLETE        Interrupt on TX byte complete
    *   UARTDEBUG_TX_STS_FIFO_EMPTY      Interrupt when TX FIFO is empty
    *   UARTDEBUG_TX_STS_FIFO_FULL       Interrupt when TX FIFO is full
    *   UARTDEBUG_TX_STS_FIFO_NOT_FULL   Interrupt when TX FIFO is not full
    *
    * Return:
    *  None.
    *
    * Theory:
    *  Enables the output of specific status bits to the interrupt controller
    *
    *******************************************************************************/
    void UARTDEBUG_SetTxInterruptMode(uint8 intSrc) 
    {
        UARTDEBUG_TXSTATUS_MASK_REG = intSrc;
    }


    /*******************************************************************************
    * Function Name: UARTDEBUG_WriteTxData
    ********************************************************************************
    *
    * Summary:
    *  Places a byte of data into the transmit buffer to be sent when the bus is
    *  available without checking the TX status register. You must check status
    *  separately.
    *
    * Parameters:
    *  txDataByte: data byte
    *
    * Return:
    * None.
    *
    * Global Variables:
    *  UARTDEBUG_txBuffer - RAM buffer pointer for save data for transmission
    *  UARTDEBUG_txBufferWrite - cyclic index for write to txBuffer,
    *    incremented after each byte saved to buffer.
    *  UARTDEBUG_txBufferRead - cyclic index for read from txBuffer,
    *    checked to identify the condition to write to FIFO directly or to TX buffer
    *  UARTDEBUG_initVar - checked to identify that the component has been
    *    initialized.
    *
    * Reentrant:
    *  No.
    *
    *******************************************************************************/
    void UARTDEBUG_WriteTxData(uint8 txDataByte) 
    {
        /* If not Initialized then skip this function*/
        if(UARTDEBUG_initVar != 0u)
        {
        #if (UARTDEBUG_TX_INTERRUPT_ENABLED)

            /* Protect variables that could change on interrupt. */
            UARTDEBUG_DisableTxInt();

            if( (UARTDEBUG_txBufferRead == UARTDEBUG_txBufferWrite) &&
                ((UARTDEBUG_TXSTATUS_REG & UARTDEBUG_TX_STS_FIFO_FULL) == 0u) )
            {
                /* Add directly to the FIFO. */
                UARTDEBUG_TXDATA_REG = txDataByte;
            }
            else
            {
                if(UARTDEBUG_txBufferWrite >= UARTDEBUG_TX_BUFFER_SIZE)
                {
                    UARTDEBUG_txBufferWrite = 0u;
                }

                UARTDEBUG_txBuffer[UARTDEBUG_txBufferWrite] = txDataByte;

                /* Add to the software buffer. */
                UARTDEBUG_txBufferWrite++;
            }

            UARTDEBUG_EnableTxInt();

        #else

            /* Add directly to the FIFO. */
            UARTDEBUG_TXDATA_REG = txDataByte;

        #endif /*(UARTDEBUG_TX_INTERRUPT_ENABLED) */
        }
    }


    /*******************************************************************************
    * Function Name: UARTDEBUG_ReadTxStatus
    ********************************************************************************
    *
    * Summary:
    *  Reads the status register for the TX portion of the UART.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  Contents of the status register
    *
    * Theory:
    *  This function reads the TX status register, which is cleared on read.
    *  It is up to the user to handle all bits in this return value accordingly,
    *  even if the bit was not enabled as an interrupt source the event happened
    *  and must be handled accordingly.
    *
    *******************************************************************************/
    uint8 UARTDEBUG_ReadTxStatus(void) 
    {
        return(UARTDEBUG_TXSTATUS_REG);
    }


    /*******************************************************************************
    * Function Name: UARTDEBUG_PutChar
    ********************************************************************************
    *
    * Summary:
    *  Puts a byte of data into the transmit buffer to be sent when the bus is
    *  available. This is a blocking API that waits until the TX buffer has room to
    *  hold the data.
    *
    * Parameters:
    *  txDataByte: Byte containing the data to transmit
    *
    * Return:
    *  None.
    *
    * Global Variables:
    *  UARTDEBUG_txBuffer - RAM buffer pointer for save data for transmission
    *  UARTDEBUG_txBufferWrite - cyclic index for write to txBuffer,
    *     checked to identify free space in txBuffer and incremented after each byte
    *     saved to buffer.
    *  UARTDEBUG_txBufferRead - cyclic index for read from txBuffer,
    *     checked to identify free space in txBuffer.
    *  UARTDEBUG_initVar - checked to identify that the component has been
    *     initialized.
    *
    * Reentrant:
    *  No.
    *
    * Theory:
    *  Allows the user to transmit any byte of data in a single transfer
    *
    *******************************************************************************/
    void UARTDEBUG_PutChar(uint8 txDataByte) 
    {
    #if (UARTDEBUG_TX_INTERRUPT_ENABLED)
        /* The temporary output pointer is used since it takes two instructions
        *  to increment with a wrap, and we can't risk doing that with the real
        *  pointer and getting an interrupt in between instructions.
        */
        uint8 locTxBufferWrite;
        uint8 locTxBufferRead;

        do
        { /* Block if software buffer is full, so we don't overwrite. */

        #if ((UARTDEBUG_TX_BUFFER_SIZE > UARTDEBUG_MAX_BYTE_VALUE) && (CY_PSOC3))
            /* Disable TX interrupt to protect variables from modification */
            UARTDEBUG_DisableTxInt();
        #endif /* (UARTDEBUG_TX_BUFFER_SIZE > UARTDEBUG_MAX_BYTE_VALUE) && (CY_PSOC3) */

            locTxBufferWrite = UARTDEBUG_txBufferWrite;
            locTxBufferRead  = UARTDEBUG_txBufferRead;

        #if ((UARTDEBUG_TX_BUFFER_SIZE > UARTDEBUG_MAX_BYTE_VALUE) && (CY_PSOC3))
            /* Enable interrupt to continue transmission */
            UARTDEBUG_EnableTxInt();
        #endif /* (UARTDEBUG_TX_BUFFER_SIZE > UARTDEBUG_MAX_BYTE_VALUE) && (CY_PSOC3) */
        }
        while( (locTxBufferWrite < locTxBufferRead) ? (locTxBufferWrite == (locTxBufferRead - 1u)) :
                                ((locTxBufferWrite - locTxBufferRead) ==
                                (uint8)(UARTDEBUG_TX_BUFFER_SIZE - 1u)) );

        if( (locTxBufferRead == locTxBufferWrite) &&
            ((UARTDEBUG_TXSTATUS_REG & UARTDEBUG_TX_STS_FIFO_FULL) == 0u) )
        {
            /* Add directly to the FIFO */
            UARTDEBUG_TXDATA_REG = txDataByte;
        }
        else
        {
            if(locTxBufferWrite >= UARTDEBUG_TX_BUFFER_SIZE)
            {
                locTxBufferWrite = 0u;
            }
            /* Add to the software buffer. */
            UARTDEBUG_txBuffer[locTxBufferWrite] = txDataByte;
            locTxBufferWrite++;

            /* Finally, update the real output pointer */
        #if ((UARTDEBUG_TX_BUFFER_SIZE > UARTDEBUG_MAX_BYTE_VALUE) && (CY_PSOC3))
            UARTDEBUG_DisableTxInt();
        #endif /* (UARTDEBUG_TX_BUFFER_SIZE > UARTDEBUG_MAX_BYTE_VALUE) && (CY_PSOC3) */

            UARTDEBUG_txBufferWrite = locTxBufferWrite;

        #if ((UARTDEBUG_TX_BUFFER_SIZE > UARTDEBUG_MAX_BYTE_VALUE) && (CY_PSOC3))
            UARTDEBUG_EnableTxInt();
        #endif /* (UARTDEBUG_TX_BUFFER_SIZE > UARTDEBUG_MAX_BYTE_VALUE) && (CY_PSOC3) */

            if(0u != (UARTDEBUG_TXSTATUS_REG & UARTDEBUG_TX_STS_FIFO_EMPTY))
            {
                /* Trigger TX interrupt to send software buffer */
                UARTDEBUG_SetPendingTxInt();
            }
        }

    #else

        while((UARTDEBUG_TXSTATUS_REG & UARTDEBUG_TX_STS_FIFO_FULL) != 0u)
        {
            /* Wait for room in the FIFO */
        }

        /* Add directly to the FIFO */
        UARTDEBUG_TXDATA_REG = txDataByte;

    #endif /* UARTDEBUG_TX_INTERRUPT_ENABLED */
    }


    /*******************************************************************************
    * Function Name: UARTDEBUG_PutString
    ********************************************************************************
    *
    * Summary:
    *  Sends a NULL terminated string to the TX buffer for transmission.
    *
    * Parameters:
    *  string[]: Pointer to the null terminated string array residing in RAM or ROM
    *
    * Return:
    *  None.
    *
    * Global Variables:
    *  UARTDEBUG_initVar - checked to identify that the component has been
    *     initialized.
    *
    * Reentrant:
    *  No.
    *
    * Theory:
    *  If there is not enough memory in the TX buffer for the entire string, this
    *  function blocks until the last character of the string is loaded into the
    *  TX buffer.
    *
    *******************************************************************************/
    void UARTDEBUG_PutString(const char8 string[]) 
    {
        uint16 bufIndex = 0u;

        /* If not Initialized then skip this function */
        if(UARTDEBUG_initVar != 0u)
        {
            /* This is a blocking function, it will not exit until all data is sent */
            while(string[bufIndex] != (char8) 0)
            {
                UARTDEBUG_PutChar((uint8)string[bufIndex]);
                bufIndex++;
            }
        }
    }


    /*******************************************************************************
    * Function Name: UARTDEBUG_PutArray
    ********************************************************************************
    *
    * Summary:
    *  Places N bytes of data from a memory array into the TX buffer for
    *  transmission.
    *
    * Parameters:
    *  string[]: Address of the memory array residing in RAM or ROM.
    *  byteCount: Number of bytes to be transmitted. The type depends on TX Buffer
    *             Size parameter.
    *
    * Return:
    *  None.
    *
    * Global Variables:
    *  UARTDEBUG_initVar - checked to identify that the component has been
    *     initialized.
    *
    * Reentrant:
    *  No.
    *
    * Theory:
    *  If there is not enough memory in the TX buffer for the entire string, this
    *  function blocks until the last character of the string is loaded into the
    *  TX buffer.
    *
    *******************************************************************************/
    void UARTDEBUG_PutArray(const uint8 string[], uint8 byteCount)
                                                                    
    {
        uint8 bufIndex = 0u;

        /* If not Initialized then skip this function */
        if(UARTDEBUG_initVar != 0u)
        {
            while(bufIndex < byteCount)
            {
                UARTDEBUG_PutChar(string[bufIndex]);
                bufIndex++;
            }
        }
    }


    /*******************************************************************************
    * Function Name: UARTDEBUG_PutCRLF
    ********************************************************************************
    *
    * Summary:
    *  Writes a byte of data followed by a carriage return (0x0D) and line feed
    *  (0x0A) to the transmit buffer.
    *
    * Parameters:
    *  txDataByte: Data byte to transmit before the carriage return and line feed.
    *
    * Return:
    *  None.
    *
    * Global Variables:
    *  UARTDEBUG_initVar - checked to identify that the component has been
    *     initialized.
    *
    * Reentrant:
    *  No.
    *
    *******************************************************************************/
    void UARTDEBUG_PutCRLF(uint8 txDataByte) 
    {
        /* If not Initialized then skip this function */
        if(UARTDEBUG_initVar != 0u)
        {
            UARTDEBUG_PutChar(txDataByte);
            UARTDEBUG_PutChar(0x0Du);
            UARTDEBUG_PutChar(0x0Au);
        }
    }


    /*******************************************************************************
    * Function Name: UARTDEBUG_GetTxBufferSize
    ********************************************************************************
    *
    * Summary:
    *  Returns the number of bytes in the TX buffer which are waiting to be 
    *  transmitted.
    *  * TX software buffer is disabled (TX Buffer Size parameter is equal to 4): 
    *    returns 0 for empty TX FIFO, 1 for not full TX FIFO or 4 for full TX FIFO.
    *  * TX software buffer is enabled: returns the number of bytes in the TX 
    *    software buffer which are waiting to be transmitted. Bytes available in the
    *    TX FIFO do not count.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  Number of bytes used in the TX buffer. Return value type depends on the TX 
    *  Buffer Size parameter.
    *
    * Global Variables:
    *  UARTDEBUG_txBufferWrite - used to calculate left space.
    *  UARTDEBUG_txBufferRead - used to calculate left space.
    *
    * Reentrant:
    *  No.
    *
    * Theory:
    *  Allows the user to find out how full the TX Buffer is.
    *
    *******************************************************************************/
    uint8 UARTDEBUG_GetTxBufferSize(void)
                                                            
    {
        uint8 size;

    #if (UARTDEBUG_TX_INTERRUPT_ENABLED)

        /* Protect variables that could change on interrupt. */
        UARTDEBUG_DisableTxInt();

        if(UARTDEBUG_txBufferRead == UARTDEBUG_txBufferWrite)
        {
            size = 0u;
        }
        else if(UARTDEBUG_txBufferRead < UARTDEBUG_txBufferWrite)
        {
            size = (UARTDEBUG_txBufferWrite - UARTDEBUG_txBufferRead);
        }
        else
        {
            size = (UARTDEBUG_TX_BUFFER_SIZE - UARTDEBUG_txBufferRead) +
                    UARTDEBUG_txBufferWrite;
        }

        UARTDEBUG_EnableTxInt();

    #else

        size = UARTDEBUG_TXSTATUS_REG;

        /* Is the fifo is full. */
        if((size & UARTDEBUG_TX_STS_FIFO_FULL) != 0u)
        {
            size = UARTDEBUG_FIFO_LENGTH;
        }
        else if((size & UARTDEBUG_TX_STS_FIFO_EMPTY) != 0u)
        {
            size = 0u;
        }
        else
        {
            /* We only know there is data in the fifo. */
            size = 1u;
        }

    #endif /* (UARTDEBUG_TX_INTERRUPT_ENABLED) */

    return(size);
    }


    /*******************************************************************************
    * Function Name: UARTDEBUG_ClearTxBuffer
    ********************************************************************************
    *
    * Summary:
    *  Clears all data from the TX buffer and hardware TX FIFO.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    * Global Variables:
    *  UARTDEBUG_txBufferWrite - cleared to zero.
    *  UARTDEBUG_txBufferRead - cleared to zero.
    *
    * Reentrant:
    *  No.
    *
    * Theory:
    *  Setting the pointers to zero makes the system believe there is no data to
    *  read and writing will resume at address 0 overwriting any data that may have
    *  remained in the RAM.
    *
    * Side Effects:
    *  Data waiting in the transmit buffer is not sent; a byte that is currently
    *  transmitting finishes transmitting.
    *
    *******************************************************************************/
    void UARTDEBUG_ClearTxBuffer(void) 
    {
        uint8 enableInterrupts;

        enableInterrupts = CyEnterCriticalSection();
        /* Clear the HW FIFO */
        UARTDEBUG_TXDATA_AUX_CTL_REG |= (uint8)  UARTDEBUG_TX_FIFO_CLR;
        UARTDEBUG_TXDATA_AUX_CTL_REG &= (uint8) ~UARTDEBUG_TX_FIFO_CLR;
        CyExitCriticalSection(enableInterrupts);

    #if (UARTDEBUG_TX_INTERRUPT_ENABLED)

        /* Protect variables that could change on interrupt. */
        UARTDEBUG_DisableTxInt();

        UARTDEBUG_txBufferRead = 0u;
        UARTDEBUG_txBufferWrite = 0u;

        /* Enable Tx interrupt. */
        UARTDEBUG_EnableTxInt();

    #endif /* (UARTDEBUG_TX_INTERRUPT_ENABLED) */
    }


    /*******************************************************************************
    * Function Name: UARTDEBUG_SendBreak
    ********************************************************************************
    *
    * Summary:
    *  Transmits a break signal on the bus.
    *
    * Parameters:
    *  uint8 retMode:  Send Break return mode. See the following table for options.
    *   UARTDEBUG_SEND_BREAK - Initialize registers for break, send the Break
    *       signal and return immediately.
    *   UARTDEBUG_WAIT_FOR_COMPLETE_REINIT - Wait until break transmission is
    *       complete, reinitialize registers to normal transmission mode then return
    *   UARTDEBUG_REINIT - Reinitialize registers to normal transmission mode
    *       then return.
    *   UARTDEBUG_SEND_WAIT_REINIT - Performs both options: 
    *      UARTDEBUG_SEND_BREAK and UARTDEBUG_WAIT_FOR_COMPLETE_REINIT.
    *      This option is recommended for most cases.
    *
    * Return:
    *  None.
    *
    * Global Variables:
    *  UARTDEBUG_initVar - checked to identify that the component has been
    *     initialized.
    *  txPeriod - static variable, used for keeping TX period configuration.
    *
    * Reentrant:
    *  No.
    *
    * Theory:
    *  SendBreak function initializes registers to send 13-bit break signal. It is
    *  important to return the registers configuration to normal for continue 8-bit
    *  operation.
    *  There are 3 variants for this API usage:
    *  1) SendBreak(3) - function will send the Break signal and take care on the
    *     configuration returning. Function will block CPU until transmission
    *     complete.
    *  2) User may want to use blocking time if UART configured to the low speed
    *     operation
    *     Example for this case:
    *     SendBreak(0);     - initialize Break signal transmission
    *         Add your code here to use CPU time
    *     SendBreak(1);     - complete Break operation
    *  3) Same to 2) but user may want to initialize and use the interrupt to
    *     complete break operation.
    *     Example for this case:
    *     Initialize TX interrupt with "TX - On TX Complete" parameter
    *     SendBreak(0);     - initialize Break signal transmission
    *         Add your code here to use CPU time
    *     When interrupt appear with UARTDEBUG_TX_STS_COMPLETE status:
    *     SendBreak(2);     - complete Break operation
    *
    * Side Effects:
    *  The UARTDEBUG_SendBreak() function initializes registers to send a
    *  break signal.
    *  Break signal length depends on the break signal bits configuration.
    *  The register configuration should be reinitialized before normal 8-bit
    *  communication can continue.
    *
    *******************************************************************************/
    void UARTDEBUG_SendBreak(uint8 retMode) 
    {

        /* If not Initialized then skip this function*/
        if(UARTDEBUG_initVar != 0u)
        {
            /* Set the Counter to 13-bits and transmit a 00 byte */
            /* When that is done then reset the counter value back */
            uint8 tmpStat;

        #if(UARTDEBUG_HD_ENABLED) /* Half Duplex mode*/

            if( (retMode == UARTDEBUG_SEND_BREAK) ||
                (retMode == UARTDEBUG_SEND_WAIT_REINIT ) )
            {
                /* CTRL_HD_SEND_BREAK - sends break bits in HD mode */
                UARTDEBUG_WriteControlRegister(UARTDEBUG_ReadControlRegister() |
                                                      UARTDEBUG_CTRL_HD_SEND_BREAK);
                /* Send zeros */
                UARTDEBUG_TXDATA_REG = 0u;

                do /* Wait until transmit starts */
                {
                    tmpStat = UARTDEBUG_TXSTATUS_REG;
                }
                while((tmpStat & UARTDEBUG_TX_STS_FIFO_EMPTY) != 0u);
            }

            if( (retMode == UARTDEBUG_WAIT_FOR_COMPLETE_REINIT) ||
                (retMode == UARTDEBUG_SEND_WAIT_REINIT) )
            {
                do /* Wait until transmit complete */
                {
                    tmpStat = UARTDEBUG_TXSTATUS_REG;
                }
                while(((uint8)~tmpStat & UARTDEBUG_TX_STS_COMPLETE) != 0u);
            }

            if( (retMode == UARTDEBUG_WAIT_FOR_COMPLETE_REINIT) ||
                (retMode == UARTDEBUG_REINIT) ||
                (retMode == UARTDEBUG_SEND_WAIT_REINIT) )
            {
                UARTDEBUG_WriteControlRegister(UARTDEBUG_ReadControlRegister() &
                                              (uint8)~UARTDEBUG_CTRL_HD_SEND_BREAK);
            }

        #else /* UARTDEBUG_HD_ENABLED Full Duplex mode */

            static uint8 txPeriod;

            if( (retMode == UARTDEBUG_SEND_BREAK) ||
                (retMode == UARTDEBUG_SEND_WAIT_REINIT) )
            {
                /* CTRL_HD_SEND_BREAK - skip to send parity bit at Break signal in Full Duplex mode */
                #if( (UARTDEBUG_PARITY_TYPE != UARTDEBUG__B_UART__NONE_REVB) || \
                                    (UARTDEBUG_PARITY_TYPE_SW != 0u) )
                    UARTDEBUG_WriteControlRegister(UARTDEBUG_ReadControlRegister() |
                                                          UARTDEBUG_CTRL_HD_SEND_BREAK);
                #endif /* End UARTDEBUG_PARITY_TYPE != UARTDEBUG__B_UART__NONE_REVB  */

                #if(UARTDEBUG_TXCLKGEN_DP)
                    txPeriod = UARTDEBUG_TXBITCLKTX_COMPLETE_REG;
                    UARTDEBUG_TXBITCLKTX_COMPLETE_REG = UARTDEBUG_TXBITCTR_BREAKBITS;
                #else
                    txPeriod = UARTDEBUG_TXBITCTR_PERIOD_REG;
                    UARTDEBUG_TXBITCTR_PERIOD_REG = UARTDEBUG_TXBITCTR_BREAKBITS8X;
                #endif /* End UARTDEBUG_TXCLKGEN_DP */

                /* Send zeros */
                UARTDEBUG_TXDATA_REG = 0u;

                do /* Wait until transmit starts */
                {
                    tmpStat = UARTDEBUG_TXSTATUS_REG;
                }
                while((tmpStat & UARTDEBUG_TX_STS_FIFO_EMPTY) != 0u);
            }

            if( (retMode == UARTDEBUG_WAIT_FOR_COMPLETE_REINIT) ||
                (retMode == UARTDEBUG_SEND_WAIT_REINIT) )
            {
                do /* Wait until transmit complete */
                {
                    tmpStat = UARTDEBUG_TXSTATUS_REG;
                }
                while(((uint8)~tmpStat & UARTDEBUG_TX_STS_COMPLETE) != 0u);
            }

            if( (retMode == UARTDEBUG_WAIT_FOR_COMPLETE_REINIT) ||
                (retMode == UARTDEBUG_REINIT) ||
                (retMode == UARTDEBUG_SEND_WAIT_REINIT) )
            {

            #if(UARTDEBUG_TXCLKGEN_DP)
                UARTDEBUG_TXBITCLKTX_COMPLETE_REG = txPeriod;
            #else
                UARTDEBUG_TXBITCTR_PERIOD_REG = txPeriod;
            #endif /* End UARTDEBUG_TXCLKGEN_DP */

            #if( (UARTDEBUG_PARITY_TYPE != UARTDEBUG__B_UART__NONE_REVB) || \
                 (UARTDEBUG_PARITY_TYPE_SW != 0u) )
                UARTDEBUG_WriteControlRegister(UARTDEBUG_ReadControlRegister() &
                                                      (uint8) ~UARTDEBUG_CTRL_HD_SEND_BREAK);
            #endif /* End UARTDEBUG_PARITY_TYPE != NONE */
            }
        #endif    /* End UARTDEBUG_HD_ENABLED */
        }
    }


    /*******************************************************************************
    * Function Name: UARTDEBUG_SetTxAddressMode
    ********************************************************************************
    *
    * Summary:
    *  Configures the transmitter to signal the next bytes is address or data.
    *
    * Parameters:
    *  addressMode: 
    *       UARTDEBUG_SET_SPACE - Configure the transmitter to send the next
    *                                    byte as a data.
    *       UARTDEBUG_SET_MARK  - Configure the transmitter to send the next
    *                                    byte as an address.
    *
    * Return:
    *  None.
    *
    * Side Effects:
    *  This function sets and clears UARTDEBUG_CTRL_MARK bit in the Control
    *  register.
    *
    *******************************************************************************/
    void UARTDEBUG_SetTxAddressMode(uint8 addressMode) 
    {
        /* Mark/Space sending enable */
        if(addressMode != 0u)
        {
        #if( UARTDEBUG_CONTROL_REG_REMOVED == 0u )
            UARTDEBUG_WriteControlRegister(UARTDEBUG_ReadControlRegister() |
                                                  UARTDEBUG_CTRL_MARK);
        #endif /* End UARTDEBUG_CONTROL_REG_REMOVED == 0u */
        }
        else
        {
        #if( UARTDEBUG_CONTROL_REG_REMOVED == 0u )
            UARTDEBUG_WriteControlRegister(UARTDEBUG_ReadControlRegister() &
                                                  (uint8) ~UARTDEBUG_CTRL_MARK);
        #endif /* End UARTDEBUG_CONTROL_REG_REMOVED == 0u */
        }
    }

#endif  /* EndUARTDEBUG_TX_ENABLED */

#if(UARTDEBUG_HD_ENABLED)


    /*******************************************************************************
    * Function Name: UARTDEBUG_LoadRxConfig
    ********************************************************************************
    *
    * Summary:
    *  Loads the receiver configuration in half duplex mode. After calling this
    *  function, the UART is ready to receive data.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    * Side Effects:
    *  Valid only in half duplex mode. You must make sure that the previous
    *  transaction is complete and it is safe to unload the transmitter
    *  configuration.
    *
    *******************************************************************************/
    void UARTDEBUG_LoadRxConfig(void) 
    {
        UARTDEBUG_WriteControlRegister(UARTDEBUG_ReadControlRegister() &
                                                (uint8)~UARTDEBUG_CTRL_HD_SEND);
        UARTDEBUG_RXBITCTR_PERIOD_REG = UARTDEBUG_HD_RXBITCTR_INIT;

    #if (UARTDEBUG_RX_INTERRUPT_ENABLED)
        /* Enable RX interrupt after set RX configuration */
        UARTDEBUG_SetRxInterruptMode(UARTDEBUG_INIT_RX_INTERRUPTS_MASK);
    #endif /* (UARTDEBUG_RX_INTERRUPT_ENABLED) */
    }


    /*******************************************************************************
    * Function Name: UARTDEBUG_LoadTxConfig
    ********************************************************************************
    *
    * Summary:
    *  Loads the transmitter configuration in half duplex mode. After calling this
    *  function, the UART is ready to transmit data.
    *
    * Parameters:
    *  None.
    *
    * Return:
    *  None.
    *
    * Side Effects:
    *  Valid only in half duplex mode. You must make sure that the previous
    *  transaction is complete and it is safe to unload the receiver configuration.
    *
    *******************************************************************************/
    void UARTDEBUG_LoadTxConfig(void) 
    {
    #if (UARTDEBUG_RX_INTERRUPT_ENABLED)
        /* Disable RX interrupts before set TX configuration */
        UARTDEBUG_SetRxInterruptMode(0u);
    #endif /* (UARTDEBUG_RX_INTERRUPT_ENABLED) */

        UARTDEBUG_WriteControlRegister(UARTDEBUG_ReadControlRegister() | UARTDEBUG_CTRL_HD_SEND);
        UARTDEBUG_RXBITCTR_PERIOD_REG = UARTDEBUG_HD_TXBITCTR_INIT;
    }

#endif  /* UARTDEBUG_HD_ENABLED */


/* [] END OF FILE */
