/*******************************************************************************
* File Name: VDAC_BATTERY_CHARGE_STATE_PM.c  
* Version 1.90
*
* Description:
*  This file provides the power management source code to API for the
*  VDAC8.  
*
* Note:
*  None
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "VDAC_BATTERY_CHARGE_STATE.h"

static VDAC_BATTERY_CHARGE_STATE_backupStruct VDAC_BATTERY_CHARGE_STATE_backup;


/*******************************************************************************
* Function Name: VDAC_BATTERY_CHARGE_STATE_SaveConfig
********************************************************************************
* Summary:
*  Save the current user configuration
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
*******************************************************************************/
void VDAC_BATTERY_CHARGE_STATE_SaveConfig(void) 
{
    if (!((VDAC_BATTERY_CHARGE_STATE_CR1 & VDAC_BATTERY_CHARGE_STATE_SRC_MASK) == VDAC_BATTERY_CHARGE_STATE_SRC_UDB))
    {
        VDAC_BATTERY_CHARGE_STATE_backup.data_value = VDAC_BATTERY_CHARGE_STATE_Data;
    }
}


/*******************************************************************************
* Function Name: VDAC_BATTERY_CHARGE_STATE_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
*******************************************************************************/
void VDAC_BATTERY_CHARGE_STATE_RestoreConfig(void) 
{
    if (!((VDAC_BATTERY_CHARGE_STATE_CR1 & VDAC_BATTERY_CHARGE_STATE_SRC_MASK) == VDAC_BATTERY_CHARGE_STATE_SRC_UDB))
    {
        if((VDAC_BATTERY_CHARGE_STATE_Strobe & VDAC_BATTERY_CHARGE_STATE_STRB_MASK) == VDAC_BATTERY_CHARGE_STATE_STRB_EN)
        {
            VDAC_BATTERY_CHARGE_STATE_Strobe &= (uint8)(~VDAC_BATTERY_CHARGE_STATE_STRB_MASK);
            VDAC_BATTERY_CHARGE_STATE_Data = VDAC_BATTERY_CHARGE_STATE_backup.data_value;
            VDAC_BATTERY_CHARGE_STATE_Strobe |= VDAC_BATTERY_CHARGE_STATE_STRB_EN;
        }
        else
        {
            VDAC_BATTERY_CHARGE_STATE_Data = VDAC_BATTERY_CHARGE_STATE_backup.data_value;
        }
    }
}


/*******************************************************************************
* Function Name: VDAC_BATTERY_CHARGE_STATE_Sleep
********************************************************************************
* Summary:
*  Stop and Save the user configuration
*
* Parameters:  
*  void:  
*
* Return: 
*  void
*
* Global variables:
*  VDAC_BATTERY_CHARGE_STATE_backup.enableState:  Is modified depending on the enable 
*  state  of the block before entering sleep mode.
*
*******************************************************************************/
void VDAC_BATTERY_CHARGE_STATE_Sleep(void) 
{
    /* Save VDAC8's enable state */    
    if(VDAC_BATTERY_CHARGE_STATE_ACT_PWR_EN == (VDAC_BATTERY_CHARGE_STATE_PWRMGR & VDAC_BATTERY_CHARGE_STATE_ACT_PWR_EN))
    {
        /* VDAC8 is enabled */
        VDAC_BATTERY_CHARGE_STATE_backup.enableState = 1u;
    }
    else
    {
        /* VDAC8 is disabled */
        VDAC_BATTERY_CHARGE_STATE_backup.enableState = 0u;
    }
    
    VDAC_BATTERY_CHARGE_STATE_Stop();
    VDAC_BATTERY_CHARGE_STATE_SaveConfig();
}


/*******************************************************************************
* Function Name: VDAC_BATTERY_CHARGE_STATE_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  VDAC_BATTERY_CHARGE_STATE_backup.enableState:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void VDAC_BATTERY_CHARGE_STATE_Wakeup(void) 
{
    VDAC_BATTERY_CHARGE_STATE_RestoreConfig();
    
    if(VDAC_BATTERY_CHARGE_STATE_backup.enableState == 1u)
    {
        /* Enable VDAC8's operation */
        VDAC_BATTERY_CHARGE_STATE_Enable();

        /* Restore the data register */
        VDAC_BATTERY_CHARGE_STATE_SetValue(VDAC_BATTERY_CHARGE_STATE_Data);
    } /* Do nothing if VDAC8 was disabled before */    
}


/* [] END OF FILE */
