/*******************************************************************************
* File Name: W5200_SPI_PM.c
* Version 2.50
*
* Description:
*  This file contains the setup, control and status commands to support
*  component operations in low power mode.
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "W5200_SPI_PVT.h"

static W5200_SPI_BACKUP_STRUCT W5200_SPI_backup =
{
    W5200_SPI_DISABLED,
    W5200_SPI_BITCTR_INIT,
};


/*******************************************************************************
* Function Name: W5200_SPI_SaveConfig
********************************************************************************
*
* Summary:
*  Empty function. Included for consistency with other components.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void W5200_SPI_SaveConfig(void) 
{

}


/*******************************************************************************
* Function Name: W5200_SPI_RestoreConfig
********************************************************************************
*
* Summary:
*  Empty function. Included for consistency with other components.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void W5200_SPI_RestoreConfig(void) 
{

}


/*******************************************************************************
* Function Name: W5200_SPI_Sleep
********************************************************************************
*
* Summary:
*  Prepare SPIM Component goes to sleep.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  W5200_SPI_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void W5200_SPI_Sleep(void) 
{
    /* Save components enable state */
    W5200_SPI_backup.enableState = ((uint8) W5200_SPI_IS_ENABLED);

    W5200_SPI_Stop();
}


/*******************************************************************************
* Function Name: W5200_SPI_Wakeup
********************************************************************************
*
* Summary:
*  Prepare SPIM Component to wake up.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  W5200_SPI_backup - used when non-retention registers are restored.
*  W5200_SPI_txBufferWrite - modified every function call - resets to
*  zero.
*  W5200_SPI_txBufferRead - modified every function call - resets to
*  zero.
*  W5200_SPI_rxBufferWrite - modified every function call - resets to
*  zero.
*  W5200_SPI_rxBufferRead - modified every function call - resets to
*  zero.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void W5200_SPI_Wakeup(void) 
{
    #if(W5200_SPI_RX_SOFTWARE_BUF_ENABLED)
        W5200_SPI_rxBufferFull  = 0u;
        W5200_SPI_rxBufferRead  = 0u;
        W5200_SPI_rxBufferWrite = 0u;
    #endif /* (W5200_SPI_RX_SOFTWARE_BUF_ENABLED) */

    #if(W5200_SPI_TX_SOFTWARE_BUF_ENABLED)
        W5200_SPI_txBufferFull  = 0u;
        W5200_SPI_txBufferRead  = 0u;
        W5200_SPI_txBufferWrite = 0u;
    #endif /* (W5200_SPI_TX_SOFTWARE_BUF_ENABLED) */

    /* Clear any data from the RX and TX FIFO */
    W5200_SPI_ClearFIFO();

    /* Restore components block enable state */
    if(0u != W5200_SPI_backup.enableState)
    {
        W5200_SPI_Enable();
    }
}


/* [] END OF FILE */
