/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/
#include "project.h"
#include "dma.h"
#include "interrupts.h"

/* Generic Defines */
#define STORE_TD_CFG_ONCMPLT               (1u)

/* DMA Config for DMA_W5200_UD2 */
#define DMA_W5200_UD2_BYTES_PER_BURST      (1u)
#define DMA_W5200_UD2_REQUEST_PER_BURST    (1u)
#define DMA_W5200_UD2_SRC_BASE             (CYDEV_DMA_BASE)
#define DMA_W5200_UD2_DST_BASE             (CYDEV_PERIPH_BASE)

void InitDmaW5200RxToUd2Tx(void);
void ReleaseDmaW5200RxToUd2Tx(void);

/* Variables for DMA_W5200_UD2 */
uint8 w5200Ud2Chan;
uint8 w5200Ud2TD[1];
uint8 *w5200RxUd2TxPtr;
uint16 w5200RxUd2TxTransferCount;

/* Getter and Setter for buffers */
void SetupDmaW5200RxToUd2Tx(uint8 *data, uint16 len)
{
  while (GetDmaW5200Ud2BusyISR() != 0);
  
  w5200RxUd2TxPtr = data;
  w5200RxUd2TxTransferCount = len;
  
  ReleaseDmaW5200RxToUd2Tx();
  InitDmaW5200RxToUd2Tx();
  
  SetDmaW5200Ud2BusyISR(1);
  StartIsrUd2TxFifoNotFull();
}

void InitDmaW5200RxToUd2Tx(void)
{
  /* Init DMA, 1 byte bursts, each burst requires a request */ 
    w5200Ud2Chan = DMA_W5200_UD2_DmaInitialize(DMA_W5200_UD2_BYTES_PER_BURST, 
                                            DMA_W5200_UD2_REQUEST_PER_BURST, 
                                            HI16(DMA_W5200_UD2_SRC_BASE), 
                                            HI16(DMA_W5200_UD2_DST_BASE));
    
    w5200Ud2TD[0] = CyDmaTdAllocate();
    
    /* Configure this Td as follows */
    CyDmaTdSetConfiguration(w5200Ud2TD[0], w5200RxUd2TxTransferCount, CY_DMA_DISABLE_TD, (TD_INC_SRC_ADR | DMA_W5200_UD2__TD_TERMOUT_EN));

    /* From the memory to the UART_DUT2 */
    CyDmaTdSetAddress(w5200Ud2TD[0], LO16((uint32)w5200RxUd2TxPtr), LO16((uint32)&UART_DUT2_TXDATA_REG));
    
    /* Associate the TD with the channel */
    CyDmaChSetInitialTd(w5200Ud2Chan, w5200Ud2TD[0]); 
    
    /* Enable the channel */
    CyDmaChEnable(w5200Ud2Chan, STORE_TD_CFG_ONCMPLT);
}

void ReleaseDmaW5200RxToUd2Tx(void)
{
  CyDmaTdFree(w5200Ud2TD[0]);
  CyDmaChFree(w5200Ud2Chan);
  DMA_W5200_UD2_DmaRelease();
}

/* [] END OF FILE */
