/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/
#include "project.h"
#include "eeprom.h"

/* Generic Defines */
#define MAC_EEPROM_START            (0x00)
#define IP_EEPROM_START             (0x01) //This is sector 1 (each sector is 16 bytes) total 128 rows
#define MAC_LEN                     (6)
#define IP_LEN                      (4)
#define SECTOR_LEN                  16
/* Mutex for access to EEPROM */
static volatile int eepromBusy = 0;

/* EEPROM busy blocker */
void WaitUntilEepromAvailable(void)
{
  while (eepromBusy == 1) 
  { 
    // If this loop exits the EEPROM is free for opration
    while(EEPROM_Storage_Query() != CYRET_SUCCESS); // This will block until write or erase operations are complete
  }
}

void EepromReadSector(uint8 Sector,uint8 *Data)
{
  WaitUntilEepromAvailable();
    for( int i = 0; i < SECTOR_LEN; i++ )
  {
    Data[i]=EEPROM_Storage_ReadByte(i+(Sector*16));
  }
}

void EepromWriteSector(uint8 Sector,uint8 *Data)
{
  WaitUntilEepromAvailable();
  EEPROM_Storage_UpdateTemperature();
  EEPROM_Storage_EraseSector(Sector);
  for( int i = 0; i < SECTOR_LEN; i++ )
  {
    EEPROM_Storage_WriteByte(Data[i],i+(Sector*16));
  }
}

/* MAC and IP getter and setters */
void GetMacFromEeprom(uint8* mac)
{
  // Get the full row from EEPROM
  uint8 eepromRowBuffer[16];
  EepromReadSector(MAC_EEPROM_START, eepromRowBuffer);
  // Parse to the MAC address
  for( int i = 0; i < MAC_LEN; i++ )
  {
    mac[i] = eepromRowBuffer[i];
  }
}

void SetMacInEeprom(uint8* newMac)
{ 
  // Set new Mac in EEPROM 
  for( int i = 0; i < MAC_LEN; i++ )
  {
    EepromWriteSector(MAC_EEPROM_START, newMac);
  } 
}

void GetIpFromEeprom(uint8* ip)
{
  // Get the full row from EEPROM
  uint8 eepromRowBuffer[16];
  EepromReadSector(IP_EEPROM_START, eepromRowBuffer);
  // Get EEPROM stored IP
  for( int i = 0; i < IP_LEN; i++ )
  {
    ip[i] = eepromRowBuffer[i];
  }
}

void SetIpInEeprom(uint8* newIp)
{
  // Set new Mac in EEPROM
  for( int i = 0; i < IP_LEN; i++ )
  {
    EepromWriteSector(IP_EEPROM_START, newIp);
  }
}
/* [] END OF FILE */
