/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/
#include "project.h"
#include "ETH.h"
#include "interrupts.h"
#include "uart.h"
#include "dma.h"
#include "eeprom.h"
#include "params.h"
#include "ProjectConfig.h"

#define ETHERNET_CONTROL_SOCKET    (1000)
#define ETHERNET_PROG_SOCKET       (5000)
#define ETHERNET_BUFFER_SIZE       (2047)

//function prototypes
void RunShortDebugMode(void);
void StartControlTcpServer(void);
void StartProgTcpServer(void);
void InitComms(void);
void CommTick(void);
void EthControlTick(void);
void UartTick(void);
void DutTick(void);
void DutProgTick(void);
void EthRxToUartDut2Tx(void);
void UartDut2RxToEthTx(void);
void ClearDutProgBuffers(void);

//Globals
uint8 controlSocket = 0xFF;
static eEthServerStates_t ethControlState = eEthDisconnected;
uint8 progSocket = 0xFF;
static eEthServerStates_t ethProgState = eEthDisconnected;

uint16 OneSecondCounter =0;
_Bool OneHundredmsTick =0;
uint64 Uptime=0;
static volatile uint32 count = 0;

int main(void)  
{
  // Main variables
  uint8 Comdelay =0;
  
  /* Enable global interrupts. */
  CyGlobalIntEnable; 
  /* Start clocks */
  Clock1Khz_Start();
  /* Start timers */
  TimerOneHundredmSecond_Start();
  /* Init ISRs */
  InitISRs();
  /* Initialise Comms */
  InitComms();
  /* Open Eth */
  paramSetParam(eDutProgCommEnabled, 1);
  
  while (1) // Scheduled loop 48MHz clock = circa 145MIPS without blocking fucntions
  {     
    DutProgTick();
    
    // This will occur every 100ms
    if (OneHundredmsTick) 
    {
      OneHundredmsTick=0;
      OneSecondCounter++;
    }
    
    // This will occur every second
    if (OneSecondCounter >= 10) 
    {
      OneSecondCounter=0;   
      Comdelay++;
    }
    
    // This will occur every 3 seconds
    if (Comdelay >= 3) 
    {   
      Comdelay=0;
    }
  }
}

void StartControlTcpServer(void)
{
  ETH_TcpDisconnect(controlSocket);
  ETH_SocketClose(controlSocket);
  ethControlState = eEthDisconnected;
  controlSocket = ETH_TcpOpen(ETHERNET_CONTROL_SOCKET); 
  if (controlSocket != 0xFF)
  {
    ETH_TcpStartServer(controlSocket);
    ethControlState = eEthListening;
  }
}

void StartProgTcpServer(void)
{
  ClearDutProgBuffers();
  progSocket = ETH_TcpOpen(ETHERNET_PROG_SOCKET);
  if (progSocket != 0xFF)
  {
    ETH_TcpStartServer(progSocket);
    ethProgState = eEthListening;
  }
}

void InitComms(void) 
{ 
  // Start EEPROM
  EEPROM_Storage_Start();
     
  // Init Ethernet
  ETH_Reset();
  uint8 status = ETH_Start();
  switch(status)
  {
    case(0):
      StartControlTcpServer();
      break;
    case(1):
      break;
    case(2):
      break;
    default:
      break;
  }
}

void EthRxToUartDut2Tx(void)
{
  // If the DMA W5200 RX to UD2 TX isn't busy doing previous transfer
  if (GetDmaW5200Ud2BusyISR() == 0)
  {
    // Get the current number of bytes on ETH RX
    uint16 bytesOnEthRx = UART_GetRxBufferSize();
    if (bytesOnEthRx > 0)
    {
      bytesOnEthRx = (bytesOnEthRx > ETHERNET_BUFFER_SIZE) 
                       ? ETHERNET_BUFFER_SIZE : bytesOnEthRx;
      uint8 ethReceivedBytes[bytesOnEthRx];
      
      // Read ETH RX and create DMA to UD2 TX
      for (int i = 0; i < bytesOnEthRx; i++)
      {
        ethReceivedBytes[i] = UART_ReadRxData();
      }
      SetupDmaW5200RxToUd2Tx(ethReceivedBytes, bytesOnEthRx);
    }
  }
}

void UartDut2RxToEthTx(void)
{
  uint16 bytesOnUartRx = UART_DUT2_GetRxBufferSize();
  if (bytesOnUartRx > 0)
  {
    bytesOnUartRx = (bytesOnUartRx > ETHERNET_BUFFER_SIZE) 
                      ? ETHERNET_BUFFER_SIZE : bytesOnUartRx;
    uint8 receivedUD2Bytes[bytesOnUartRx];
    
    for (int i = 0; i < bytesOnUartRx; i++)
    {
      receivedUD2Bytes[i] = UART_DUT2_ReadRxData();
    }
    //ETH_TcpSend(progSocket, receivedUD2Bytes, bytesOnUartRx);
  }
}

void ClearDutProgBuffers(void)
{
  ETH_TcpDisconnect(progSocket);
  ETH_SocketClose(progSocket);
  ethProgState = eEthDisconnected;
      
  /* Clear the ETH buffers */
  ETH_ClearBuffers();
  
  /* Clear UART DUT 2 buffers */
  UART_DUT2_ClearRxBuffer();
  UART_DUT2_ClearTxBuffer();
}

void DutProgTick(void)
{
  if (paramGetParam(eDutProgCommEnabled))
  { 
    /* Start UART DUT 2 */
    UART_DUT2_Start();
    UART_Start();
      
    /* ETH RX to UART DUT 2 TX */
    EthRxToUartDut2Tx();
    
    /* UART DUT 2 RX to ETH TX */
    UartDut2RxToEthTx();
  }
  else
  {
    /* Disconnect and close the sockets after disabling */
    if (ethProgState != eEthDisconnected) 
    {
      // Clear the buffers
      ClearDutProgBuffers();
      
      /* Turn the UART DUT 2 off */
      UART_DUT2_Stop();
      UART_Stop();
    }
  } 
}

/* [] END OF FILE */
