/*******************************************************************************
* File Name: UARTDEBUG.h
* Version 2.50
*
* Description:
*  Contains the function prototypes and constants available to the UART
*  user module.
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/


#if !defined(CY_UART_UARTDEBUG_H)
#define CY_UART_UARTDEBUG_H

#include "cyfitter.h"
#include "cytypes.h"
#include "CyLib.h" /* For CyEnterCriticalSection() and CyExitCriticalSection() functions */


/***************************************
* Conditional Compilation Parameters
***************************************/

#define UARTDEBUG_RX_ENABLED                     (1u)
#define UARTDEBUG_TX_ENABLED                     (1u)
#define UARTDEBUG_HD_ENABLED                     (0u)
#define UARTDEBUG_RX_INTERRUPT_ENABLED           (0u)
#define UARTDEBUG_TX_INTERRUPT_ENABLED           (0u)
#define UARTDEBUG_INTERNAL_CLOCK_USED            (1u)
#define UARTDEBUG_RXHW_ADDRESS_ENABLED           (0u)
#define UARTDEBUG_OVER_SAMPLE_COUNT              (8u)
#define UARTDEBUG_PARITY_TYPE                    (0u)
#define UARTDEBUG_PARITY_TYPE_SW                 (0u)
#define UARTDEBUG_BREAK_DETECT                   (0u)
#define UARTDEBUG_BREAK_BITS_TX                  (13u)
#define UARTDEBUG_BREAK_BITS_RX                  (13u)
#define UARTDEBUG_TXCLKGEN_DP                    (1u)
#define UARTDEBUG_USE23POLLING                   (1u)
#define UARTDEBUG_FLOW_CONTROL                   (0u)
#define UARTDEBUG_CLK_FREQ                       (0u)
#define UARTDEBUG_TX_BUFFER_SIZE                 (4u)
#define UARTDEBUG_RX_BUFFER_SIZE                 (4u)

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component UART_v2_50 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */

#if defined(UARTDEBUG_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG)
    #define UARTDEBUG_CONTROL_REG_REMOVED            (0u)
#else
    #define UARTDEBUG_CONTROL_REG_REMOVED            (1u)
#endif /* End UARTDEBUG_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG */


/***************************************
*      Data Structure Definition
***************************************/

/* Sleep Mode API Support */
typedef struct UARTDEBUG_backupStruct_
{
    uint8 enableState;

    #if(UARTDEBUG_CONTROL_REG_REMOVED == 0u)
        uint8 cr;
    #endif /* End UARTDEBUG_CONTROL_REG_REMOVED */

} UARTDEBUG_BACKUP_STRUCT;


/***************************************
*       Function Prototypes
***************************************/

void UARTDEBUG_Start(void) ;
void UARTDEBUG_Stop(void) ;
uint8 UARTDEBUG_ReadControlRegister(void) ;
void UARTDEBUG_WriteControlRegister(uint8 control) ;

void UARTDEBUG_Init(void) ;
void UARTDEBUG_Enable(void) ;
void UARTDEBUG_SaveConfig(void) ;
void UARTDEBUG_RestoreConfig(void) ;
void UARTDEBUG_Sleep(void) ;
void UARTDEBUG_Wakeup(void) ;

/* Only if RX is enabled */
#if( (UARTDEBUG_RX_ENABLED) || (UARTDEBUG_HD_ENABLED) )

    #if (UARTDEBUG_RX_INTERRUPT_ENABLED)
        #define UARTDEBUG_EnableRxInt()  CyIntEnable (UARTDEBUG_RX_VECT_NUM)
        #define UARTDEBUG_DisableRxInt() CyIntDisable(UARTDEBUG_RX_VECT_NUM)
        CY_ISR_PROTO(UARTDEBUG_RXISR);
    #endif /* UARTDEBUG_RX_INTERRUPT_ENABLED */

    void UARTDEBUG_SetRxAddressMode(uint8 addressMode)
                                                           ;
    void UARTDEBUG_SetRxAddress1(uint8 address) ;
    void UARTDEBUG_SetRxAddress2(uint8 address) ;

    void  UARTDEBUG_SetRxInterruptMode(uint8 intSrc) ;
    uint8 UARTDEBUG_ReadRxData(void) ;
    uint8 UARTDEBUG_ReadRxStatus(void) ;
    uint8 UARTDEBUG_GetChar(void) ;
    uint16 UARTDEBUG_GetByte(void) ;
    uint8 UARTDEBUG_GetRxBufferSize(void)
                                                            ;
    void UARTDEBUG_ClearRxBuffer(void) ;

    /* Obsolete functions, defines for backward compatible */
    #define UARTDEBUG_GetRxInterruptSource   UARTDEBUG_ReadRxStatus

#endif /* End (UARTDEBUG_RX_ENABLED) || (UARTDEBUG_HD_ENABLED) */

/* Only if TX is enabled */
#if(UARTDEBUG_TX_ENABLED || UARTDEBUG_HD_ENABLED)

    #if(UARTDEBUG_TX_INTERRUPT_ENABLED)
        #define UARTDEBUG_EnableTxInt()  CyIntEnable (UARTDEBUG_TX_VECT_NUM)
        #define UARTDEBUG_DisableTxInt() CyIntDisable(UARTDEBUG_TX_VECT_NUM)
        #define UARTDEBUG_SetPendingTxInt() CyIntSetPending(UARTDEBUG_TX_VECT_NUM)
        #define UARTDEBUG_ClearPendingTxInt() CyIntClearPending(UARTDEBUG_TX_VECT_NUM)
        CY_ISR_PROTO(UARTDEBUG_TXISR);
    #endif /* UARTDEBUG_TX_INTERRUPT_ENABLED */

    void UARTDEBUG_SetTxInterruptMode(uint8 intSrc) ;
    void UARTDEBUG_WriteTxData(uint8 txDataByte) ;
    uint8 UARTDEBUG_ReadTxStatus(void) ;
    void UARTDEBUG_PutChar(uint8 txDataByte) ;
    void UARTDEBUG_PutString(const char8 string[]) ;
    void UARTDEBUG_PutArray(const uint8 string[], uint8 byteCount)
                                                            ;
    void UARTDEBUG_PutCRLF(uint8 txDataByte) ;
    void UARTDEBUG_ClearTxBuffer(void) ;
    void UARTDEBUG_SetTxAddressMode(uint8 addressMode) ;
    void UARTDEBUG_SendBreak(uint8 retMode) ;
    uint8 UARTDEBUG_GetTxBufferSize(void)
                                                            ;
    /* Obsolete functions, defines for backward compatible */
    #define UARTDEBUG_PutStringConst         UARTDEBUG_PutString
    #define UARTDEBUG_PutArrayConst          UARTDEBUG_PutArray
    #define UARTDEBUG_GetTxInterruptSource   UARTDEBUG_ReadTxStatus

#endif /* End UARTDEBUG_TX_ENABLED || UARTDEBUG_HD_ENABLED */

#if(UARTDEBUG_HD_ENABLED)
    void UARTDEBUG_LoadRxConfig(void) ;
    void UARTDEBUG_LoadTxConfig(void) ;
#endif /* End UARTDEBUG_HD_ENABLED */


/* Communication bootloader APIs */
#if defined(CYDEV_BOOTLOADER_IO_COMP) && ((CYDEV_BOOTLOADER_IO_COMP == CyBtldr_UARTDEBUG) || \
                                          (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Custom_Interface))
    /* Physical layer functions */
    void    UARTDEBUG_CyBtldrCommStart(void) CYSMALL ;
    void    UARTDEBUG_CyBtldrCommStop(void) CYSMALL ;
    void    UARTDEBUG_CyBtldrCommReset(void) CYSMALL ;
    cystatus UARTDEBUG_CyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut) CYSMALL
             ;
    cystatus UARTDEBUG_CyBtldrCommRead(uint8 pData[], uint16 size, uint16 * count, uint8 timeOut) CYSMALL
             ;

    #if (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_UARTDEBUG)
        #define CyBtldrCommStart    UARTDEBUG_CyBtldrCommStart
        #define CyBtldrCommStop     UARTDEBUG_CyBtldrCommStop
        #define CyBtldrCommReset    UARTDEBUG_CyBtldrCommReset
        #define CyBtldrCommWrite    UARTDEBUG_CyBtldrCommWrite
        #define CyBtldrCommRead     UARTDEBUG_CyBtldrCommRead
    #endif  /* (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_UARTDEBUG) */

    /* Byte to Byte time out for detecting end of block data from host */
    #define UARTDEBUG_BYTE2BYTE_TIME_OUT (25u)
    #define UARTDEBUG_PACKET_EOP         (0x17u) /* End of packet defined by bootloader */
    #define UARTDEBUG_WAIT_EOP_DELAY     (5u)    /* Additional 5ms to wait for End of packet */
    #define UARTDEBUG_BL_CHK_DELAY_MS    (1u)    /* Time Out quantity equal 1mS */

#endif /* CYDEV_BOOTLOADER_IO_COMP */


/***************************************
*          API Constants
***************************************/
/* Parameters for SetTxAddressMode API*/
#define UARTDEBUG_SET_SPACE      (0x00u)
#define UARTDEBUG_SET_MARK       (0x01u)

/* Status Register definitions */
#if( (UARTDEBUG_TX_ENABLED) || (UARTDEBUG_HD_ENABLED) )
    #if(UARTDEBUG_TX_INTERRUPT_ENABLED)
        #define UARTDEBUG_TX_VECT_NUM            (uint8)UARTDEBUG_TXInternalInterrupt__INTC_NUMBER
        #define UARTDEBUG_TX_PRIOR_NUM           (uint8)UARTDEBUG_TXInternalInterrupt__INTC_PRIOR_NUM
    #endif /* UARTDEBUG_TX_INTERRUPT_ENABLED */

    #define UARTDEBUG_TX_STS_COMPLETE_SHIFT          (0x00u)
    #define UARTDEBUG_TX_STS_FIFO_EMPTY_SHIFT        (0x01u)
    #define UARTDEBUG_TX_STS_FIFO_NOT_FULL_SHIFT     (0x03u)
    #if(UARTDEBUG_TX_ENABLED)
        #define UARTDEBUG_TX_STS_FIFO_FULL_SHIFT     (0x02u)
    #else /* (UARTDEBUG_HD_ENABLED) */
        #define UARTDEBUG_TX_STS_FIFO_FULL_SHIFT     (0x05u)  /* Needs MD=0 */
    #endif /* (UARTDEBUG_TX_ENABLED) */

    #define UARTDEBUG_TX_STS_COMPLETE            (uint8)(0x01u << UARTDEBUG_TX_STS_COMPLETE_SHIFT)
    #define UARTDEBUG_TX_STS_FIFO_EMPTY          (uint8)(0x01u << UARTDEBUG_TX_STS_FIFO_EMPTY_SHIFT)
    #define UARTDEBUG_TX_STS_FIFO_FULL           (uint8)(0x01u << UARTDEBUG_TX_STS_FIFO_FULL_SHIFT)
    #define UARTDEBUG_TX_STS_FIFO_NOT_FULL       (uint8)(0x01u << UARTDEBUG_TX_STS_FIFO_NOT_FULL_SHIFT)
#endif /* End (UARTDEBUG_TX_ENABLED) || (UARTDEBUG_HD_ENABLED)*/

#if( (UARTDEBUG_RX_ENABLED) || (UARTDEBUG_HD_ENABLED) )
    #if(UARTDEBUG_RX_INTERRUPT_ENABLED)
        #define UARTDEBUG_RX_VECT_NUM            (uint8)UARTDEBUG_RXInternalInterrupt__INTC_NUMBER
        #define UARTDEBUG_RX_PRIOR_NUM           (uint8)UARTDEBUG_RXInternalInterrupt__INTC_PRIOR_NUM
    #endif /* UARTDEBUG_RX_INTERRUPT_ENABLED */
    #define UARTDEBUG_RX_STS_MRKSPC_SHIFT            (0x00u)
    #define UARTDEBUG_RX_STS_BREAK_SHIFT             (0x01u)
    #define UARTDEBUG_RX_STS_PAR_ERROR_SHIFT         (0x02u)
    #define UARTDEBUG_RX_STS_STOP_ERROR_SHIFT        (0x03u)
    #define UARTDEBUG_RX_STS_OVERRUN_SHIFT           (0x04u)
    #define UARTDEBUG_RX_STS_FIFO_NOTEMPTY_SHIFT     (0x05u)
    #define UARTDEBUG_RX_STS_ADDR_MATCH_SHIFT        (0x06u)
    #define UARTDEBUG_RX_STS_SOFT_BUFF_OVER_SHIFT    (0x07u)

    #define UARTDEBUG_RX_STS_MRKSPC           (uint8)(0x01u << UARTDEBUG_RX_STS_MRKSPC_SHIFT)
    #define UARTDEBUG_RX_STS_BREAK            (uint8)(0x01u << UARTDEBUG_RX_STS_BREAK_SHIFT)
    #define UARTDEBUG_RX_STS_PAR_ERROR        (uint8)(0x01u << UARTDEBUG_RX_STS_PAR_ERROR_SHIFT)
    #define UARTDEBUG_RX_STS_STOP_ERROR       (uint8)(0x01u << UARTDEBUG_RX_STS_STOP_ERROR_SHIFT)
    #define UARTDEBUG_RX_STS_OVERRUN          (uint8)(0x01u << UARTDEBUG_RX_STS_OVERRUN_SHIFT)
    #define UARTDEBUG_RX_STS_FIFO_NOTEMPTY    (uint8)(0x01u << UARTDEBUG_RX_STS_FIFO_NOTEMPTY_SHIFT)
    #define UARTDEBUG_RX_STS_ADDR_MATCH       (uint8)(0x01u << UARTDEBUG_RX_STS_ADDR_MATCH_SHIFT)
    #define UARTDEBUG_RX_STS_SOFT_BUFF_OVER   (uint8)(0x01u << UARTDEBUG_RX_STS_SOFT_BUFF_OVER_SHIFT)
    #define UARTDEBUG_RX_HW_MASK                     (0x7Fu)
#endif /* End (UARTDEBUG_RX_ENABLED) || (UARTDEBUG_HD_ENABLED) */

/* Control Register definitions */
#define UARTDEBUG_CTRL_HD_SEND_SHIFT                 (0x00u) /* 1 enable TX part in Half Duplex mode */
#define UARTDEBUG_CTRL_HD_SEND_BREAK_SHIFT           (0x01u) /* 1 send BREAK signal in Half Duplez mode */
#define UARTDEBUG_CTRL_MARK_SHIFT                    (0x02u) /* 1 sets mark, 0 sets space */
#define UARTDEBUG_CTRL_PARITY_TYPE0_SHIFT            (0x03u) /* Defines the type of parity implemented */
#define UARTDEBUG_CTRL_PARITY_TYPE1_SHIFT            (0x04u) /* Defines the type of parity implemented */
#define UARTDEBUG_CTRL_RXADDR_MODE0_SHIFT            (0x05u)
#define UARTDEBUG_CTRL_RXADDR_MODE1_SHIFT            (0x06u)
#define UARTDEBUG_CTRL_RXADDR_MODE2_SHIFT            (0x07u)

#define UARTDEBUG_CTRL_HD_SEND               (uint8)(0x01u << UARTDEBUG_CTRL_HD_SEND_SHIFT)
#define UARTDEBUG_CTRL_HD_SEND_BREAK         (uint8)(0x01u << UARTDEBUG_CTRL_HD_SEND_BREAK_SHIFT)
#define UARTDEBUG_CTRL_MARK                  (uint8)(0x01u << UARTDEBUG_CTRL_MARK_SHIFT)
#define UARTDEBUG_CTRL_PARITY_TYPE_MASK      (uint8)(0x03u << UARTDEBUG_CTRL_PARITY_TYPE0_SHIFT)
#define UARTDEBUG_CTRL_RXADDR_MODE_MASK      (uint8)(0x07u << UARTDEBUG_CTRL_RXADDR_MODE0_SHIFT)

/* StatusI Register Interrupt Enable Control Bits. As defined by the Register map for the AUX Control Register */
#define UARTDEBUG_INT_ENABLE                         (0x10u)

/* Bit Counter (7-bit) Control Register Bit Definitions. As defined by the Register map for the AUX Control Register */
#define UARTDEBUG_CNTR_ENABLE                        (0x20u)

/*   Constants for SendBreak() "retMode" parameter  */
#define UARTDEBUG_SEND_BREAK                         (0x00u)
#define UARTDEBUG_WAIT_FOR_COMPLETE_REINIT           (0x01u)
#define UARTDEBUG_REINIT                             (0x02u)
#define UARTDEBUG_SEND_WAIT_REINIT                   (0x03u)

#define UARTDEBUG_OVER_SAMPLE_8                      (8u)
#define UARTDEBUG_OVER_SAMPLE_16                     (16u)

#define UARTDEBUG_BIT_CENTER                         (UARTDEBUG_OVER_SAMPLE_COUNT - 2u)

#define UARTDEBUG_FIFO_LENGTH                        (4u)
#define UARTDEBUG_NUMBER_OF_START_BIT                (1u)
#define UARTDEBUG_MAX_BYTE_VALUE                     (0xFFu)

/* 8X always for count7 implementation */
#define UARTDEBUG_TXBITCTR_BREAKBITS8X   ((UARTDEBUG_BREAK_BITS_TX * UARTDEBUG_OVER_SAMPLE_8) - 1u)
/* 8X or 16X for DP implementation */
#define UARTDEBUG_TXBITCTR_BREAKBITS ((UARTDEBUG_BREAK_BITS_TX * UARTDEBUG_OVER_SAMPLE_COUNT) - 1u)

#define UARTDEBUG_HALF_BIT_COUNT   \
                            (((UARTDEBUG_OVER_SAMPLE_COUNT / 2u) + (UARTDEBUG_USE23POLLING * 1u)) - 2u)
#if (UARTDEBUG_OVER_SAMPLE_COUNT == UARTDEBUG_OVER_SAMPLE_8)
    #define UARTDEBUG_HD_TXBITCTR_INIT   (((UARTDEBUG_BREAK_BITS_TX + \
                            UARTDEBUG_NUMBER_OF_START_BIT) * UARTDEBUG_OVER_SAMPLE_COUNT) - 1u)

    /* This parameter is increased on the 2 in 2 out of 3 mode to sample voting in the middle */
    #define UARTDEBUG_RXBITCTR_INIT  ((((UARTDEBUG_BREAK_BITS_RX + UARTDEBUG_NUMBER_OF_START_BIT) \
                            * UARTDEBUG_OVER_SAMPLE_COUNT) + UARTDEBUG_HALF_BIT_COUNT) - 1u)

#else /* UARTDEBUG_OVER_SAMPLE_COUNT == UARTDEBUG_OVER_SAMPLE_16 */
    #define UARTDEBUG_HD_TXBITCTR_INIT   ((8u * UARTDEBUG_OVER_SAMPLE_COUNT) - 1u)
    /* 7bit counter need one more bit for OverSampleCount = 16 */
    #define UARTDEBUG_RXBITCTR_INIT      (((7u * UARTDEBUG_OVER_SAMPLE_COUNT) - 1u) + \
                                                      UARTDEBUG_HALF_BIT_COUNT)
#endif /* End UARTDEBUG_OVER_SAMPLE_COUNT */

#define UARTDEBUG_HD_RXBITCTR_INIT                   UARTDEBUG_RXBITCTR_INIT


/***************************************
* Global variables external identifier
***************************************/

extern uint8 UARTDEBUG_initVar;
#if (UARTDEBUG_TX_INTERRUPT_ENABLED && UARTDEBUG_TX_ENABLED)
    extern volatile uint8 UARTDEBUG_txBuffer[UARTDEBUG_TX_BUFFER_SIZE];
    extern volatile uint8 UARTDEBUG_txBufferRead;
    extern uint8 UARTDEBUG_txBufferWrite;
#endif /* (UARTDEBUG_TX_INTERRUPT_ENABLED && UARTDEBUG_TX_ENABLED) */
#if (UARTDEBUG_RX_INTERRUPT_ENABLED && (UARTDEBUG_RX_ENABLED || UARTDEBUG_HD_ENABLED))
    extern uint8 UARTDEBUG_errorStatus;
    extern volatile uint8 UARTDEBUG_rxBuffer[UARTDEBUG_RX_BUFFER_SIZE];
    extern volatile uint8 UARTDEBUG_rxBufferRead;
    extern volatile uint8 UARTDEBUG_rxBufferWrite;
    extern volatile uint8 UARTDEBUG_rxBufferLoopDetect;
    extern volatile uint8 UARTDEBUG_rxBufferOverflow;
    #if (UARTDEBUG_RXHW_ADDRESS_ENABLED)
        extern volatile uint8 UARTDEBUG_rxAddressMode;
        extern volatile uint8 UARTDEBUG_rxAddressDetected;
    #endif /* (UARTDEBUG_RXHW_ADDRESS_ENABLED) */
#endif /* (UARTDEBUG_RX_INTERRUPT_ENABLED && (UARTDEBUG_RX_ENABLED || UARTDEBUG_HD_ENABLED)) */


/***************************************
* Enumerated Types and Parameters
***************************************/

#define UARTDEBUG__B_UART__AM_SW_BYTE_BYTE 1
#define UARTDEBUG__B_UART__AM_SW_DETECT_TO_BUFFER 2
#define UARTDEBUG__B_UART__AM_HW_BYTE_BY_BYTE 3
#define UARTDEBUG__B_UART__AM_HW_DETECT_TO_BUFFER 4
#define UARTDEBUG__B_UART__AM_NONE 0

#define UARTDEBUG__B_UART__NONE_REVB 0
#define UARTDEBUG__B_UART__EVEN_REVB 1
#define UARTDEBUG__B_UART__ODD_REVB 2
#define UARTDEBUG__B_UART__MARK_SPACE_REVB 3



/***************************************
*    Initial Parameter Constants
***************************************/

/* UART shifts max 8 bits, Mark/Space functionality working if 9 selected */
#define UARTDEBUG_NUMBER_OF_DATA_BITS    ((8u > 8u) ? 8u : 8u)
#define UARTDEBUG_NUMBER_OF_STOP_BITS    (1u)

#if (UARTDEBUG_RXHW_ADDRESS_ENABLED)
    #define UARTDEBUG_RX_ADDRESS_MODE    (0u)
    #define UARTDEBUG_RX_HW_ADDRESS1     (0u)
    #define UARTDEBUG_RX_HW_ADDRESS2     (0u)
#endif /* (UARTDEBUG_RXHW_ADDRESS_ENABLED) */

#define UARTDEBUG_INIT_RX_INTERRUPTS_MASK \
                                  (uint8)((1 << UARTDEBUG_RX_STS_FIFO_NOTEMPTY_SHIFT) \
                                        | (0 << UARTDEBUG_RX_STS_MRKSPC_SHIFT) \
                                        | (0 << UARTDEBUG_RX_STS_ADDR_MATCH_SHIFT) \
                                        | (0 << UARTDEBUG_RX_STS_PAR_ERROR_SHIFT) \
                                        | (0 << UARTDEBUG_RX_STS_STOP_ERROR_SHIFT) \
                                        | (0 << UARTDEBUG_RX_STS_BREAK_SHIFT) \
                                        | (0 << UARTDEBUG_RX_STS_OVERRUN_SHIFT))

#define UARTDEBUG_INIT_TX_INTERRUPTS_MASK \
                                  (uint8)((0 << UARTDEBUG_TX_STS_COMPLETE_SHIFT) \
                                        | (0 << UARTDEBUG_TX_STS_FIFO_EMPTY_SHIFT) \
                                        | (0 << UARTDEBUG_TX_STS_FIFO_FULL_SHIFT) \
                                        | (0 << UARTDEBUG_TX_STS_FIFO_NOT_FULL_SHIFT))


/***************************************
*              Registers
***************************************/

#ifdef UARTDEBUG_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG
    #define UARTDEBUG_CONTROL_REG \
                            (* (reg8 *) UARTDEBUG_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG )
    #define UARTDEBUG_CONTROL_PTR \
                            (  (reg8 *) UARTDEBUG_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG )
#endif /* End UARTDEBUG_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG */

#if(UARTDEBUG_TX_ENABLED)
    #define UARTDEBUG_TXDATA_REG          (* (reg8 *) UARTDEBUG_BUART_sTX_TxShifter_u0__F0_REG)
    #define UARTDEBUG_TXDATA_PTR          (  (reg8 *) UARTDEBUG_BUART_sTX_TxShifter_u0__F0_REG)
    #define UARTDEBUG_TXDATA_AUX_CTL_REG  (* (reg8 *) UARTDEBUG_BUART_sTX_TxShifter_u0__DP_AUX_CTL_REG)
    #define UARTDEBUG_TXDATA_AUX_CTL_PTR  (  (reg8 *) UARTDEBUG_BUART_sTX_TxShifter_u0__DP_AUX_CTL_REG)
    #define UARTDEBUG_TXSTATUS_REG        (* (reg8 *) UARTDEBUG_BUART_sTX_TxSts__STATUS_REG)
    #define UARTDEBUG_TXSTATUS_PTR        (  (reg8 *) UARTDEBUG_BUART_sTX_TxSts__STATUS_REG)
    #define UARTDEBUG_TXSTATUS_MASK_REG   (* (reg8 *) UARTDEBUG_BUART_sTX_TxSts__MASK_REG)
    #define UARTDEBUG_TXSTATUS_MASK_PTR   (  (reg8 *) UARTDEBUG_BUART_sTX_TxSts__MASK_REG)
    #define UARTDEBUG_TXSTATUS_ACTL_REG   (* (reg8 *) UARTDEBUG_BUART_sTX_TxSts__STATUS_AUX_CTL_REG)
    #define UARTDEBUG_TXSTATUS_ACTL_PTR   (  (reg8 *) UARTDEBUG_BUART_sTX_TxSts__STATUS_AUX_CTL_REG)

    /* DP clock */
    #if(UARTDEBUG_TXCLKGEN_DP)
        #define UARTDEBUG_TXBITCLKGEN_CTR_REG        \
                                        (* (reg8 *) UARTDEBUG_BUART_sTX_sCLOCK_TxBitClkGen__D0_REG)
        #define UARTDEBUG_TXBITCLKGEN_CTR_PTR        \
                                        (  (reg8 *) UARTDEBUG_BUART_sTX_sCLOCK_TxBitClkGen__D0_REG)
        #define UARTDEBUG_TXBITCLKTX_COMPLETE_REG    \
                                        (* (reg8 *) UARTDEBUG_BUART_sTX_sCLOCK_TxBitClkGen__D1_REG)
        #define UARTDEBUG_TXBITCLKTX_COMPLETE_PTR    \
                                        (  (reg8 *) UARTDEBUG_BUART_sTX_sCLOCK_TxBitClkGen__D1_REG)
    #else     /* Count7 clock*/
        #define UARTDEBUG_TXBITCTR_PERIOD_REG    \
                                        (* (reg8 *) UARTDEBUG_BUART_sTX_sCLOCK_TxBitCounter__PERIOD_REG)
        #define UARTDEBUG_TXBITCTR_PERIOD_PTR    \
                                        (  (reg8 *) UARTDEBUG_BUART_sTX_sCLOCK_TxBitCounter__PERIOD_REG)
        #define UARTDEBUG_TXBITCTR_CONTROL_REG   \
                                        (* (reg8 *) UARTDEBUG_BUART_sTX_sCLOCK_TxBitCounter__CONTROL_AUX_CTL_REG)
        #define UARTDEBUG_TXBITCTR_CONTROL_PTR   \
                                        (  (reg8 *) UARTDEBUG_BUART_sTX_sCLOCK_TxBitCounter__CONTROL_AUX_CTL_REG)
        #define UARTDEBUG_TXBITCTR_COUNTER_REG   \
                                        (* (reg8 *) UARTDEBUG_BUART_sTX_sCLOCK_TxBitCounter__COUNT_REG)
        #define UARTDEBUG_TXBITCTR_COUNTER_PTR   \
                                        (  (reg8 *) UARTDEBUG_BUART_sTX_sCLOCK_TxBitCounter__COUNT_REG)
    #endif /* UARTDEBUG_TXCLKGEN_DP */

#endif /* End UARTDEBUG_TX_ENABLED */

#if(UARTDEBUG_HD_ENABLED)

    #define UARTDEBUG_TXDATA_REG             (* (reg8 *) UARTDEBUG_BUART_sRX_RxShifter_u0__F1_REG )
    #define UARTDEBUG_TXDATA_PTR             (  (reg8 *) UARTDEBUG_BUART_sRX_RxShifter_u0__F1_REG )
    #define UARTDEBUG_TXDATA_AUX_CTL_REG     (* (reg8 *) UARTDEBUG_BUART_sRX_RxShifter_u0__DP_AUX_CTL_REG)
    #define UARTDEBUG_TXDATA_AUX_CTL_PTR     (  (reg8 *) UARTDEBUG_BUART_sRX_RxShifter_u0__DP_AUX_CTL_REG)

    #define UARTDEBUG_TXSTATUS_REG           (* (reg8 *) UARTDEBUG_BUART_sRX_RxSts__STATUS_REG )
    #define UARTDEBUG_TXSTATUS_PTR           (  (reg8 *) UARTDEBUG_BUART_sRX_RxSts__STATUS_REG )
    #define UARTDEBUG_TXSTATUS_MASK_REG      (* (reg8 *) UARTDEBUG_BUART_sRX_RxSts__MASK_REG )
    #define UARTDEBUG_TXSTATUS_MASK_PTR      (  (reg8 *) UARTDEBUG_BUART_sRX_RxSts__MASK_REG )
    #define UARTDEBUG_TXSTATUS_ACTL_REG      (* (reg8 *) UARTDEBUG_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
    #define UARTDEBUG_TXSTATUS_ACTL_PTR      (  (reg8 *) UARTDEBUG_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
#endif /* End UARTDEBUG_HD_ENABLED */

#if( (UARTDEBUG_RX_ENABLED) || (UARTDEBUG_HD_ENABLED) )
    #define UARTDEBUG_RXDATA_REG             (* (reg8 *) UARTDEBUG_BUART_sRX_RxShifter_u0__F0_REG )
    #define UARTDEBUG_RXDATA_PTR             (  (reg8 *) UARTDEBUG_BUART_sRX_RxShifter_u0__F0_REG )
    #define UARTDEBUG_RXADDRESS1_REG         (* (reg8 *) UARTDEBUG_BUART_sRX_RxShifter_u0__D0_REG )
    #define UARTDEBUG_RXADDRESS1_PTR         (  (reg8 *) UARTDEBUG_BUART_sRX_RxShifter_u0__D0_REG )
    #define UARTDEBUG_RXADDRESS2_REG         (* (reg8 *) UARTDEBUG_BUART_sRX_RxShifter_u0__D1_REG )
    #define UARTDEBUG_RXADDRESS2_PTR         (  (reg8 *) UARTDEBUG_BUART_sRX_RxShifter_u0__D1_REG )
    #define UARTDEBUG_RXDATA_AUX_CTL_REG     (* (reg8 *) UARTDEBUG_BUART_sRX_RxShifter_u0__DP_AUX_CTL_REG)

    #define UARTDEBUG_RXBITCTR_PERIOD_REG    (* (reg8 *) UARTDEBUG_BUART_sRX_RxBitCounter__PERIOD_REG )
    #define UARTDEBUG_RXBITCTR_PERIOD_PTR    (  (reg8 *) UARTDEBUG_BUART_sRX_RxBitCounter__PERIOD_REG )
    #define UARTDEBUG_RXBITCTR_CONTROL_REG   \
                                        (* (reg8 *) UARTDEBUG_BUART_sRX_RxBitCounter__CONTROL_AUX_CTL_REG )
    #define UARTDEBUG_RXBITCTR_CONTROL_PTR   \
                                        (  (reg8 *) UARTDEBUG_BUART_sRX_RxBitCounter__CONTROL_AUX_CTL_REG )
    #define UARTDEBUG_RXBITCTR_COUNTER_REG   (* (reg8 *) UARTDEBUG_BUART_sRX_RxBitCounter__COUNT_REG )
    #define UARTDEBUG_RXBITCTR_COUNTER_PTR   (  (reg8 *) UARTDEBUG_BUART_sRX_RxBitCounter__COUNT_REG )

    #define UARTDEBUG_RXSTATUS_REG           (* (reg8 *) UARTDEBUG_BUART_sRX_RxSts__STATUS_REG )
    #define UARTDEBUG_RXSTATUS_PTR           (  (reg8 *) UARTDEBUG_BUART_sRX_RxSts__STATUS_REG )
    #define UARTDEBUG_RXSTATUS_MASK_REG      (* (reg8 *) UARTDEBUG_BUART_sRX_RxSts__MASK_REG )
    #define UARTDEBUG_RXSTATUS_MASK_PTR      (  (reg8 *) UARTDEBUG_BUART_sRX_RxSts__MASK_REG )
    #define UARTDEBUG_RXSTATUS_ACTL_REG      (* (reg8 *) UARTDEBUG_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
    #define UARTDEBUG_RXSTATUS_ACTL_PTR      (  (reg8 *) UARTDEBUG_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
#endif /* End  (UARTDEBUG_RX_ENABLED) || (UARTDEBUG_HD_ENABLED) */

#if(UARTDEBUG_INTERNAL_CLOCK_USED)
    /* Register to enable or disable the digital clocks */
    #define UARTDEBUG_INTCLOCK_CLKEN_REG     (* (reg8 *) UARTDEBUG_IntClock__PM_ACT_CFG)
    #define UARTDEBUG_INTCLOCK_CLKEN_PTR     (  (reg8 *) UARTDEBUG_IntClock__PM_ACT_CFG)

    /* Clock mask for this clock. */
    #define UARTDEBUG_INTCLOCK_CLKEN_MASK    UARTDEBUG_IntClock__PM_ACT_MSK
#endif /* End UARTDEBUG_INTERNAL_CLOCK_USED */


/***************************************
*       Register Constants
***************************************/

#if(UARTDEBUG_TX_ENABLED)
    #define UARTDEBUG_TX_FIFO_CLR            (0x01u) /* FIFO0 CLR */
#endif /* End UARTDEBUG_TX_ENABLED */

#if(UARTDEBUG_HD_ENABLED)
    #define UARTDEBUG_TX_FIFO_CLR            (0x02u) /* FIFO1 CLR */
#endif /* End UARTDEBUG_HD_ENABLED */

#if( (UARTDEBUG_RX_ENABLED) || (UARTDEBUG_HD_ENABLED) )
    #define UARTDEBUG_RX_FIFO_CLR            (0x01u) /* FIFO0 CLR */
#endif /* End  (UARTDEBUG_RX_ENABLED) || (UARTDEBUG_HD_ENABLED) */


/***************************************
* The following code is DEPRECATED and
* should not be used in new projects.
***************************************/

/* UART v2_40 obsolete definitions */
#define UARTDEBUG_WAIT_1_MS      UARTDEBUG_BL_CHK_DELAY_MS   

#define UARTDEBUG_TXBUFFERSIZE   UARTDEBUG_TX_BUFFER_SIZE
#define UARTDEBUG_RXBUFFERSIZE   UARTDEBUG_RX_BUFFER_SIZE

#if (UARTDEBUG_RXHW_ADDRESS_ENABLED)
    #define UARTDEBUG_RXADDRESSMODE  UARTDEBUG_RX_ADDRESS_MODE
    #define UARTDEBUG_RXHWADDRESS1   UARTDEBUG_RX_HW_ADDRESS1
    #define UARTDEBUG_RXHWADDRESS2   UARTDEBUG_RX_HW_ADDRESS2
    /* Backward compatible define */
    #define UARTDEBUG_RXAddressMode  UARTDEBUG_RXADDRESSMODE
#endif /* (UARTDEBUG_RXHW_ADDRESS_ENABLED) */

/* UART v2_30 obsolete definitions */
#define UARTDEBUG_initvar                    UARTDEBUG_initVar

#define UARTDEBUG_RX_Enabled                 UARTDEBUG_RX_ENABLED
#define UARTDEBUG_TX_Enabled                 UARTDEBUG_TX_ENABLED
#define UARTDEBUG_HD_Enabled                 UARTDEBUG_HD_ENABLED
#define UARTDEBUG_RX_IntInterruptEnabled     UARTDEBUG_RX_INTERRUPT_ENABLED
#define UARTDEBUG_TX_IntInterruptEnabled     UARTDEBUG_TX_INTERRUPT_ENABLED
#define UARTDEBUG_InternalClockUsed          UARTDEBUG_INTERNAL_CLOCK_USED
#define UARTDEBUG_RXHW_Address_Enabled       UARTDEBUG_RXHW_ADDRESS_ENABLED
#define UARTDEBUG_OverSampleCount            UARTDEBUG_OVER_SAMPLE_COUNT
#define UARTDEBUG_ParityType                 UARTDEBUG_PARITY_TYPE

#if( UARTDEBUG_TX_ENABLED && (UARTDEBUG_TXBUFFERSIZE > UARTDEBUG_FIFO_LENGTH))
    #define UARTDEBUG_TXBUFFER               UARTDEBUG_txBuffer
    #define UARTDEBUG_TXBUFFERREAD           UARTDEBUG_txBufferRead
    #define UARTDEBUG_TXBUFFERWRITE          UARTDEBUG_txBufferWrite
#endif /* End UARTDEBUG_TX_ENABLED */
#if( ( UARTDEBUG_RX_ENABLED || UARTDEBUG_HD_ENABLED ) && \
     (UARTDEBUG_RXBUFFERSIZE > UARTDEBUG_FIFO_LENGTH) )
    #define UARTDEBUG_RXBUFFER               UARTDEBUG_rxBuffer
    #define UARTDEBUG_RXBUFFERREAD           UARTDEBUG_rxBufferRead
    #define UARTDEBUG_RXBUFFERWRITE          UARTDEBUG_rxBufferWrite
    #define UARTDEBUG_RXBUFFERLOOPDETECT     UARTDEBUG_rxBufferLoopDetect
    #define UARTDEBUG_RXBUFFER_OVERFLOW      UARTDEBUG_rxBufferOverflow
#endif /* End UARTDEBUG_RX_ENABLED */

#ifdef UARTDEBUG_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG
    #define UARTDEBUG_CONTROL                UARTDEBUG_CONTROL_REG
#endif /* End UARTDEBUG_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG */

#if(UARTDEBUG_TX_ENABLED)
    #define UARTDEBUG_TXDATA                 UARTDEBUG_TXDATA_REG
    #define UARTDEBUG_TXSTATUS               UARTDEBUG_TXSTATUS_REG
    #define UARTDEBUG_TXSTATUS_MASK          UARTDEBUG_TXSTATUS_MASK_REG
    #define UARTDEBUG_TXSTATUS_ACTL          UARTDEBUG_TXSTATUS_ACTL_REG
    /* DP clock */
    #if(UARTDEBUG_TXCLKGEN_DP)
        #define UARTDEBUG_TXBITCLKGEN_CTR        UARTDEBUG_TXBITCLKGEN_CTR_REG
        #define UARTDEBUG_TXBITCLKTX_COMPLETE    UARTDEBUG_TXBITCLKTX_COMPLETE_REG
    #else     /* Count7 clock*/
        #define UARTDEBUG_TXBITCTR_PERIOD        UARTDEBUG_TXBITCTR_PERIOD_REG
        #define UARTDEBUG_TXBITCTR_CONTROL       UARTDEBUG_TXBITCTR_CONTROL_REG
        #define UARTDEBUG_TXBITCTR_COUNTER       UARTDEBUG_TXBITCTR_COUNTER_REG
    #endif /* UARTDEBUG_TXCLKGEN_DP */
#endif /* End UARTDEBUG_TX_ENABLED */

#if(UARTDEBUG_HD_ENABLED)
    #define UARTDEBUG_TXDATA                 UARTDEBUG_TXDATA_REG
    #define UARTDEBUG_TXSTATUS               UARTDEBUG_TXSTATUS_REG
    #define UARTDEBUG_TXSTATUS_MASK          UARTDEBUG_TXSTATUS_MASK_REG
    #define UARTDEBUG_TXSTATUS_ACTL          UARTDEBUG_TXSTATUS_ACTL_REG
#endif /* End UARTDEBUG_HD_ENABLED */

#if( (UARTDEBUG_RX_ENABLED) || (UARTDEBUG_HD_ENABLED) )
    #define UARTDEBUG_RXDATA                 UARTDEBUG_RXDATA_REG
    #define UARTDEBUG_RXADDRESS1             UARTDEBUG_RXADDRESS1_REG
    #define UARTDEBUG_RXADDRESS2             UARTDEBUG_RXADDRESS2_REG
    #define UARTDEBUG_RXBITCTR_PERIOD        UARTDEBUG_RXBITCTR_PERIOD_REG
    #define UARTDEBUG_RXBITCTR_CONTROL       UARTDEBUG_RXBITCTR_CONTROL_REG
    #define UARTDEBUG_RXBITCTR_COUNTER       UARTDEBUG_RXBITCTR_COUNTER_REG
    #define UARTDEBUG_RXSTATUS               UARTDEBUG_RXSTATUS_REG
    #define UARTDEBUG_RXSTATUS_MASK          UARTDEBUG_RXSTATUS_MASK_REG
    #define UARTDEBUG_RXSTATUS_ACTL          UARTDEBUG_RXSTATUS_ACTL_REG
#endif /* End  (UARTDEBUG_RX_ENABLED) || (UARTDEBUG_HD_ENABLED) */

#if(UARTDEBUG_INTERNAL_CLOCK_USED)
    #define UARTDEBUG_INTCLOCK_CLKEN         UARTDEBUG_INTCLOCK_CLKEN_REG
#endif /* End UARTDEBUG_INTERNAL_CLOCK_USED */

#define UARTDEBUG_WAIT_FOR_COMLETE_REINIT    UARTDEBUG_WAIT_FOR_COMPLETE_REINIT

#endif  /* CY_UART_UARTDEBUG_H */


/* [] END OF FILE */
